"FractionBySpecies" <-
function(mat1,mat3,n,p,k,print.cum=FALSE) 

# This function computes the fraction of the response variable variance
# explained by canonical axes 1, 2, 3, ... and by the whole canonical analysis.
#
# mat1 (nxp) is the site-by-species data table Y
# spSS (p) is a vector containing the species sums-of-squares
# mat3 (pxk) contains the species scores (matrix UL) from PL's rda
# mat4 (pxk) contains the results, found in the output element $rdaFitSpe
# The output element  $VarExpl  contains the % of each species'
#    variance explained by the canonical analysis
#
# Use of the function:
#	Frac=FractionBySpecies(Y.mat,toto$rdaUSc2)
#	Frac$rdaFitSpe   table of Cumulative fit per species as fraction of
#                    variance of species
#	Frac$VarExpl     vector of total % fit per species after all axes
{
	#	n=nrow(mat1)
	#	p=ncol(mat1)
	#	k=ncol(mat3)
	spSS=diag(var(mat1))
	mat4=matrix(NA,p,k)
	VarExpl=vector(mode="numeric",p)
	if(k!=1){
		for(i in 1:p) {
		   ss=0.0
		   for(j in 1:k) {
		      ss=ss+(mat3[i,j]^2)
		      if(ss<0.00000000001)
		      	ss<-0
		      mat4[i,j]=100*ss/spSS[i]
		      if(is.na(mat4[i,j]))
		      	mat4[i,j]=0
		   } 
		   VarExpl[i]=mat4[i,k]
		}
	}else{
		for(i in 1:p) {
		   ss=0.0
		   if(ss<0.00000000001)
		      ss<-0
		      mat4[i,k]=100*ss/spSS[i]
		   if(is.na(mat4[i,k]))
		      mat4[i,k]=0
		}
	}
	varnames<-colnames(mat1,do.NULL = FALSE, prefix = "p")
	names(VarExpl)<-varnames
	rownames(mat4)<-varnames
	colnames(mat4)<-colnames(mat4,do.NULL=FALSE,prefix="Cum.axis")
	if(print.cum==TRUE){
	#	cat('Debug: Values of n =',n,'  p =',p,'  k =',k,'\n','\n')
		cat('Cumulative fit of species as fraction of their variance ',
			'after 1, 2, 3 ... axes','\n')
		print(mat4)
		cat('\n')
	}else{}
	return(list(rdaFitSpe=mat4,VarExpl=VarExpl))
}

