"analyse" <-
function(extract.data=NA, VIS=NA, alt.sect=NULL, 
	flag=0, use= "VT", keep=NA, method="RDA", class.vec=NULL,
	validation.perc=0.30, nperm=999, criterion="calinski", 
	select.grpmt=TRUE, min.g=2, max.g=25, grpmts.plot=TRUE, 
	dateformat="%d-%b-%Y", timesep=":", print.res=TRUE){
	
# DESCRIPTION

# This routines aims to analyse the two matrices generated by the extract 
# algorythm.  

# INPUT

# extract.data		This can either be loaded list output by the extract function, the path to the "???extract.RData" file which contains the list or 
#					the extracted variables
#					The default if NA; a selection browser will show up 
# VIS=NA		This is a file containing the visual analysis of the 
#					footprint areas during consecutive one second laps
#					The default if NA; a selection browser will show up
#					This file might not be necessary depending on with type of 
#					analysis is performed.  If required, this file must have in 
#					is first column the date, in the second the time and in the #					other the visual variables.  Colnames is suitables.
# alt.sect=NA		Is the echoes variables are to be analysed based on there 
#					altitude of acquisition. If so a matrix of (n x 2) shall be 
#					given.  In column 1, the start (inclusive) and in column 2 
#					is the end (exclusive) of each altitude sections, each lines
#					corresponds to a separate altitude section on which the 
#					analysis will be performed independently
# keep=NA	A file giving through time ranges which section to keep in 
#					the analysis. The principle is the same as alt.sect by 
#					instead of altitude values, time values are entered.
#					E.G.: "~/STABLE.TXT"
# flags=0				Corresponds to the flags states.  It can be either, 
#					2	<-	Both first and second echoes, 
#					1.5	<-	Both first echoes and second echoes rise,
#					1 	<-	Uses only the first echoes
# use			Run the analysis on either, 
#					"VT" 	<- 	on the combined set of intensity and extracted 
#								variables (stand for VI and VE) 
#					"VE" 	<- 	on the extracted variables only
#					"VI" 	<-  on the intensity variables only				
# method			Correspond to either Redondancy analysis "RDA", or linear
#					discriminant analysis "LDA".
#					"RDA" method requires a matrix of response variable, a set 
#					of site visual descriptors describing continuously the 
#					studied area. By default since K.means is set to true, 
#					groupements will be made and shown in the plot using either
#					ellipses or stars.
#					"LDA" method requires a grouping vector, if 
#					no vector is given a classification partition is obtained 
#					through k-means.
#
# validation.perc	If "LDA" method is used, a model is produced and output. 
#					If a value of 100% is given a model will be made. If 70% is 
#					used 70% of the data will be used to construct the model and 
#					the other random 30% will be used to validate the model.
#					If 0% is used a pop up browser will show and will ask you 
#					to load and existing model and run the data on it.
#
# class.vec=NA	A vector class for every sonar return, if none one will be
#					created using K-means on the sonar data.  If more than one
#					altitude section is made, class.vec will be estimated for 
#					each submatrices. Work only for LDA
#
# k-means=TRUE		If set to FALSE class.vec will not be computed
# nperm				The number of permutation used
# criterion			Out of 15 criterion can be used to group the data.  The
#					default is "calinski".
# min.g				The minimum number of group, default = 2 
# max.g				The maximum number of group, default = 25
# save.LDA.model	Save the model created in LDA, if NA you will be asked
#					if a path is given it will save it. If NA it will not be 
#					asked.
# lda.model			If validation.perc is 0 or if a path is provided, the 
#					lda.model is loaded and used to predict the group 
#					appatenance

	
	#times2keep="~/STABLE.TXT"

	#path.REM a file with time ranges in row tell defining which echo to remove
	calll=match.call()
	vvvv<-system.time({
		warnings()
		options(warn=1)
		lct <- Sys.getlocale("LC_TIME")
		Sys.setlocale("LC_TIME", "C")
		use=toupper(use)
		s<-list()
		#### Librairies and source codes
		library(MASS)
		
		jkl=1
		
		#### Reading
		a<-system.time({
			if(length(extract.data)==1){
				if(is.na(extract.data)){ # No input
					cat("Please select one output file created by the extract",
						"function\n")
					extract.data<-file.choose()
					extract.data<-check.file(extract.data,type="extrac.RData")
					extract.data<-load(extract.data)
				}else{ #This is a path
					extract.data<-check.file(extract.data,type="extrac.RData")
					extract.data<-load(extract.data)
				}
			}else{} #Extract was already loaded
			s$VE<-extract.data$VE
			extract.data$VE<-0
			s$VI<-extract.data$VI
			extract.data$VI<-0
			s$j.refdate<-min(as.numeric(as.Date(s$VE[,1],
				dateformat="%Y-%m-%d")))
			tmp<-time2spm(s$VE[,1], s$j.refdate, dateformat="%Y-%m-%d", 
				s$VE[,2], timesep)
			tmp0<-c("TimeSPM", colnames(s$VE)[-c(1,2)])
			s$VE<-cbind(tmp, matrix(as.numeric(s$VE[,-c(1,2)]), 
				nrow=dim(s$VE)[1]))
			colnames(s$VE)<-tmp0
			tmp0<-c("TimeSPM", colnames(s$VI)[-c(1,2)])
			s$VI<-cbind(tmp, matrix(as.numeric(s$VI[,-c(1,2)]), 
				nrow=dim(s$VI)[1]))
			colnames(s$VI)<-tmp0
		})
		a[3]<-sprintf("%.2f", a[3])
		cat(jkl, "- Extract.data list has been read! Required time", a[3],
			"sec.\n")
		jkl<-jkl+1
		
		#### Looking at the class.vec parameter
		#### Creation of the ID matrix
		if(is.null(class.vec)){
			s$ID<-data.frame(s$VI[,1:3], rep(0,nrow(s$VI)))
		}else{
			if(length(class.vec)!=length(s$VI[,1])){
				s$ID<-data.frame(s$VI[,1:3], rep(0,nrow(s$VI)))
			}else{
				s$ID<-data.frame(s$VI[,1:3], class.vec)
			}
		}
		colnames(s$ID)<-c("TimeSPM", "Altitude", "Flags", "Class")

		#### Selection of the data to analyse
		if(flag!=2 & flag!=1.5 & flag!=1){
			flag=0
			while(flag==0){
				cat("Out of", nrow(s$ID), "echoes returns:\n")
				tmp<-matrix("Found", 3, 5);tmp[c(9, 11, 12)]="Lack"
				tmp[1,5]=length(which(s$ID[,3]==2))
				tmp[2,5]=length(which(s$ID[,3]==1.5))
				tmp[3,5]=length(which(s$ID[,3]==1))
				colnames(tmp)<-c("Rise E1", "Set E1", "Rise E2", "Set E2",
					"Nombre of echoes")
				rownames(tmp)<-c("Echo set: 2", "Echo Set: 1.5", "Echo Set: 1")
				print(tmp)
				cat("Select which echo set you want to analyse, type either 2,",
					"1.5 or 1 \n")
				flag<-scan("", nlines=1,quiet=TRUE)
				if(flag==2 | flag==1.5 | flag==1){
				}else{
					cat("Wrong selection\n")
					flag<-0
				}
			}
		}else{}
		#### Consequent removal of inadequate data
		rem<-which(s$ID[,mn("Flags", mat=s$ID)]<flag)
		s$VI<-s$VI[-rem,]
		s$VE<-s$VE[-rem,]
		s$ID<-s$ID[-rem,]
		
		#### Reading the keep parameter, see if there is some specific times on 
		#### which the analysis shall be perform
		tmp=0
		if(length(keep)==1){ 
			if (!is.na(keep)){ # We have a path
				keep<-check.file(keep)
				s$keep<-read.table(keep)
			}else{ # We don't have any keep limits
				tmp=1
			}
		}else{ # Limits were already loaded
			s$keep<-keep
		}
		#### Consequent filtering based on the keep limits
		if(tmp!=1){
			a<-system.time({
				s$keep[,1]<-time2spm(s$keep[,1], s$j.refdate, dateformat, 
					s$keep[,2], timesep)
				s$keep[,2]<-time2spm(s$keep[,3], s$j.refdate, dateformat, 
					s$keep[,4], timesep)
				s$keep<-s$keep[,-c(3,4)]
				s<-specifictimes(s, path=keep)
			})
			a[3]<-sprintf("%.2f", a[3])
			cat(jkl, "- Selection of the echos to keep is done!",
			"Required time", a[3], "sec.\n")
			jkl<-jkl+1	
		}else{}
		
		#### Matrix clean up
		#### Since we use ID, VI and VE id's are removed 
		s$VI<-s$VI[,-c(1:3)]
		s$VE<-s$VE[,-c(1:3)]
		a<-system.time(s<-cleanup.NA.Inf(s))
		a[3]<-sprintf("%.2f", a[3])
		cat(jkl, "- Cleanup of NA and Inf values, done! Required time", a[3],
			"sec.\n")
		jkl<-jkl+1

		# Data initial tranformation to reduce the impact of strong values and
		# try have variable distribution that ressemble a normal distribution		
		a<-system.time(tmp<-transf(VE=s$VE,VI=s$VI, analyse=use))
		s$VE=tmp$VE
		s$VE.table=tmp$VE.table
		s$VI=tmp$VI
		a[3]<-sprintf("%.2f", a[3])
		cat(jkl, "- VE and VI matrix transformation, done! Required time", 
		a[3],"sec.\n")
		jkl<-jkl+1
		s$VT<-cbind(s$VE,s$VI)
		
		# If we require a data matrix visual description
		method=toupper(method)
		if(method=="RDA"){
			s$data.VIS<-list()
			a<-system.time({
				if(length(VIS)>1){ # a loaded matrix
					s$VIS<-as.matrix(VIS)
				}else{# Looking for a path
					VIS<-check.file(VIS, type="VIS")
					s$VIS<-read.table(VIS)
				}
				rm(VIS)
				rown<-time2spm(date=s$VIS[,1], refdate=s$j.refdate, 
					dateformat=dateformat, timesep=timesep, time=s$VIS[,2])
				s$VIS<-s$VIS[,-c(1,2)]
				coln<-colnames(s$VIS)
				s$VIS<-matrix(as.numeric(s$VIS),ncol=dim(s$VIS)[2])
				rownames(s$VIS)<-as.character(rown); rm(rown)
				colnames(s$VIS)<-coln; rm(coln)
			})
			a[3]<-sprintf("%.2f", a[3])
			cat(jkl, "- Reading the visual analysis data done! Required time", 	
				a[3],"sec.\n")
				jkl<-jkl+1
				
			#### This screening is done considering that each video samples 
			#### describes the continuom of one second
			a<-system.time({
				s$screening<-data.screening(s$VIS, timespm=s$ID[,1])
				#### Screened data
				s$VIS<-s$VIS[-s$screening$rem.vis,]
				tmp00<-s[[which(names(s)==use)]]
				tmp00<-tmp00[s$screening$keep,]
				s$ID<-s$ID[s$screening$keep,]
			})
			a[3]<-sprintf("%.2f", a[3])
			cat(jkl, "- Finding sonar data matching the VIS file,", 
			"done! Required time", a[3], "sec.\n")
			jkl<-jkl+1	
			a<-system.time({
				tmp<-variation.filter(s$VIS, scaling=TRUE, binary=TRUE, 
					min.numb=10)
				s$VIS<-tmp$mat     
			})
			a[3]<-sprintf("%.2f", a[3])
			cat(jkl, "- Filtering VIS binary data out!", 
				" Required time", a[3], "sec.\n")
			jkl<-jkl+1
			#### In order to compare echo with the visual survey, echoes are 	
			#### average per second so that they matched the visual survey 
			#### sampling times.
			#### It would yeild much more data if the visual sample were
			#### duplicated but it would introduce a bias. 
			a<-system.time({
				#### Because every echoes found within the one seconds are 
				#### respectively averaged, s$ID[,4] or classes are to be zero 
				#### since it would not make sense to average them.
				s$ID[,4]<-0
				tmp<-as.factor(trunc(s$ID[,1]))
				tmp00<-cbind(s$ID,tmp00)
				tmp00<-do.call("rbind", lapply(levels(tmp),
							function(y){ 
								xx<-which(tmp==y)
								if(length(xx)==1){
									tmp00[which(tmp==y),]
								}else{
									apply(tmp00[which(tmp==y),],2, mean)
								}
							}
						))
				s$ID<-tmp00[,1:4]
				tmp00<-tmp00[,-c(1:4)]
			})
			a[3]<-sprintf("%.2f", a[3])
			cat(jkl, "- Averaging of echo variables per second, done!", 
				"Required time", a[3], "sec.\n")
			jkl<-jkl+1
			s[[which(names(s)==use)]]<-tmp00
			rm(tmp00)
		}
		#Presentement qu'un seul range doit tre utilis	
		a<-system.time(s$data<-splitByAlt(mat=s[[which(names(s)==use)]], 
			ID=s$ID, alt.sect))
		a[3]<-sprintf("%.2f", a[3])
		cat(jkl, "- Split the variables matrices based on 'alt.sect', done!",
			"Required time", a[3], "sec.\n")
		jkl<-jkl+1
		#### For every altitude section analysis is done 
		#### K.means is specially done in this loop to make sure that grouping 
		#### is not influenced by wrong altitude values
		s$kmeans.res<-list()
		for(i in 1:length(s$data)){
			s$kmeans.res[[i]]<-list()
			s$kmeans.res[[i]]$groups<-matrix(NA, nrow(s$data[[i]]), 
				(max.g-min.g+1))
			s$kmeans.res[[i]]$index<-rep(NA,(max.g-min.g+1))
			s$kmeans.res[[i]]$selection<-NA
			#### First we look if there is variable with no or nearly no 
			#### variation
			id.temp<-s$data[[i]][,1:4]
			s$data[[i]]<-as.matrix(s$data[[i]][,-c(1:4)])
			a<-system.time({
				tmp<-variation.filter(s$data[[i]], ID=id.temp, scaling=TRUE, 
					binary=FALSE, min.numb=10)
				s$data[[i]]<-tmp$mat
				id.temp=tmp$ID
			})
			a[3]<-sprintf("%.2f", a[3])
			cat(jkl, "- Variation filter applied of the data! Required time",
				a[3], "sec.\n")
			jkl<-jkl+1
			
			if(method=="LDA" & is.null(class.vec)){
				#### Find the groupments with cascadeKM)
				a<-system.time({
					tmp <- cascadeKM(s$data[[i]], min.g, max.g, iter = nperm, 
						criterion = criterion)
					groups<-tmp$partition
					index<-tmp$results[2,]
				})
				a[3]<-sprintf("%.2f", a[3])
				cat(jkl, "- Groupments by k-means, done! Required time",
					a[3], "sec.\n")
				jkl<-jkl+1
				tmp<-plotKM(tmp, grpmts.plot=grpmts.plot, gridcol=NA)
				select<-tmp$best.grps
				if(grpmts.plot==FALSE)
					select.grmpt=FALSE
				groups<-tmp$x
				if(select.grpmt==TRUE){
					ttmp=0
					cat("Is the", names(select), "partition, the best one :", 
						"Yes=1 or No=0\n")
					ttmp<-scan("",nlines=1)
					while(ttmp!=1){
						cat("How many groups has to be keep in the partition?")
						tttmp<-as.numeric(scan("",nlines=1))
						if(tttmp-1>ncol(groups)){
							ttmp=0
							cat("The number typed is outside the partition")
						}else{
							select<-tttmp-1
							names(select)<-colnames(groups)[tttmp-1]
							ttmp=1
						}
					}
				}else{}
				id.temp[,4]<-groups[,select]
				tmp<-variation.filter(s$data[[i]], ID=id.temp, scaling=FALSE, 
					binary=FALSE, min.numb=10)
				s$data[[i]]<-tmp$mat
				id.temp=tmp$ID
				s$kmeans.res[[i]]$groups<-groups
				s$kmeans.res[[i]]$index<-index
				s$kmeans.res[[i]]$selection<-select
			}else{
				tmp<-variation.filter(s$data[[i]], ID=id.temp, scaling=FALSE, 
					binary=FALSE, min.numb=10)
				s$data[[i]]<-tmp$mat
				id.temp=tmp$ID
			}
			if(method=="RDA"){
				s$screening<-data.screening(s$VIS, timespm=id.temp[,1])
				#### Screened data
				s$data.VIS[[i]]<-s$VIS[-s$screening$rem.vis,]
			    tmp<-variation.filter(s$data.VIS[[i]], scaling=TRUE, 
					binary=TRUE, min.numb=10)
				s$data.VIS[[i]]<-tmp$mat
			}else{}
			tmp<-variation.filter(s$data[[i]], ID=id.temp, scaling=FALSE, 
				binary=FALSE, min.numb=10)
			s$data[[i]]<-tmp$mat
			id.temp=tmp$ID
			name<-names(s$data)[i]
			a<-system.time(s$data[[i]]<-variable.selection(s$data[[i]],
				seuil=0.725, name=name))
			a[3]<-sprintf("%.2f", a[3])
			cat(jkl, "- Filtering based on correlation and variance",
				"inflation factors, done! Required time", a[3], "sec.\n")
			jkl<-jkl+1	
			s$data[[i]]<-cbind(id.temp,s$data[[i]])
		}
		#### print("Commencement de l'evaluation du skewness moyen des matrices 
		#### pour les variables VI")
		#### source("~/.../intra.group.skew.test.R")
		#### s$intra.group.matrix.skew<-intra.group.skew.test(s$int.transf)
		#	s$fwd.res<-list()
		#	s$fwd.res$int.vs.all<-forward.sel(s$data$....[,-(1:4)],s$VIS)
		#return(s)
		if(method=="RDA"){
			print("Running RDA")
			#### Effectue l'analyse de la RDA
			s$results<-list()
			for(m in 1:length(s$data)){
				#### Effectue l'analyse de la RDA
				s$results[[m]]<-rdaTest(s$data.VIS[[m]], s$data[[m]][,-c(1:4)], 
					scale.Y=FALSE, testF=TRUE, nperm=999, print.res=print.res, 
					print.cum=print.res)
			}
		}else{
			print("Running LDA")
			s$results<-list()
			for(m in 1:length(s$data)){
				#### Effectue l'analyse de la LDA
				s$results[[m]]<-ldaTest(X.mat=as.matrix(s$data[[m]][,-c(1:4)]), 
				group=s$data[[m]][,4], print.res=print.res, alpha=0.05, 
				cross=validation.perc)
			}
		}
		s<-list(results=s$results,call=calll)
	})
	vvvv[3]<-sprintf("%.2f",vvvv[3]/60) 
	print(paste("Total time required ", vvvv[3]," min."), seq="")
	Sys.setlocale("LC_TIME", lct)
	return(s)
}

