"area.centroid.time" <-
function(sonardata, debut.E1, fin.E1, debut.E2, fin.E2, Pmx.sE1, Pmx.sE2, spacing, Flags){

# DESCRIPTION

# For both the first and second echo, we extract for their rise and set section 
# the area under the curve, the x and y position of their centroid, and their 
# time laps

# INPUT

# sonardata			The data matrix containing the sonar return intensity values
# debut.E1			The start position of the first echo
# fin.E1			The end position of the first echo
# debut.E2			The start position of the second echo
# fin.E2			The end position of the second echo
# Pmx.sE1			The maximum intensity position of the first echo
# Pmx.sE2			The maximum intensity position of the second echo
# spacing			The new timelaps at which the intensities values were 
#					resampled
# Flags				A Vector of marker describing how many echoes are within one
#					return
	necho<-nrow(sonardata)
	Area.R.E1<-rep(NA, necho);Area.S.E1<-rep(NA, necho);
	Area.T.E1<-rep(NA, necho);Area.R.E2<-rep(NA, necho);
	Area.S.E2<-rep(NA, necho);Area.T.E2<-rep(NA, necho);
	C.R.x.E1<-rep(NA, necho);C.R.y.E1<-rep(NA, necho);
	C.S.x.E1<-rep(NA, necho);C.S.y.E1<-rep(NA, necho);
	C.R.x.E2<-rep(NA, necho);C.R.y.E2<-rep(NA, necho);
	C.S.x.E2<-rep(NA, necho);C.S.y.E2<-rep(NA, necho);
	C.T.x.E1<-rep(NA, necho);C.T.y.E1<-rep(NA, necho);
	C.T.x.E2<-rep(NA, necho);C.T.y.E2<-rep(NA, necho);
	Time.S.E1<-rep(NA, necho);Time.R.E1<-rep(NA, necho);
	Time.T.E1<-rep(NA, necho);Time.S.E2<-rep(NA, necho);
	Time.R.E2<-rep(NA, necho);Time.T.E2<-rep(NA, necho);
	use<-which(Flags>=1)
	for (i in use){
		Area.R.E1[i]<-sum(sonardata[i,(debut.E1[i]:(Pmx.sE1[i]-1))])*spacing
		Area.S.E1[i]<-sum(sonardata[i,(Pmx.sE1[i]:(fin.E1[i]-1))])*spacing
		Area.T.E1[i]<-sum(sonardata[i,(debut.E1[i]:(fin.E1[i]-1))])*spacing
		if(Flags[i]>=1.5){
			Area.R.E2[i]<-sum(sonardata[i,(debut.E2[i]:(Pmx.sE2[i]-1))])*spacing
		}else{}
		if(Flags[i]==2){
			Area.R.E2[i]<-sum(sonardata[i,(debut.E2[i]:(Pmx.sE2[i]-1))])*spacing
			Area.S.E2[i]<-sum(sonardata[i,(Pmx.sE2[i]:(fin.E2[i]-1))])*spacing
			Area.T.E2[i]<-sum(sonardata[i,(debut.E2[i]:(fin.E2[i]-1))])*spacing
		}else{}
		tmp<-tct(sonardata[i,], debut.E1[i], Pmx.sE1[i], spacing=spacing)
		Area.R.E1[i]<-Area.R.E1[i]+tmp$triangle
		C.R.x.E1[i]<-tmp$trix+tmp$cx
		C.R.y.E1[i]<-tmp$triy+tmp$cy
		tmp<-tct(sonardata[i,], Pmx.sE1[i], fin.E1[i], spacing=spacing)
		Area.S.E1[i]<-Area.S.E1[i]+tmp$triangle
		Area.T.E1[i]<-Area.R.E1[i]+Area.S.E1[i]
		C.S.x.E1[i]<-tmp$trix+tmp$cx
		C.S.y.E1[i]<-tmp$triy+tmp$cy
		C.T.x.E1[i]<-C.R.x.E1[i]+C.S.x.E1[i]
		C.T.y.E1[i]<-C.R.y.E1[i]+C.S.y.E1[i]
		if(Flags[i]>=1.5){
			tmp<-tct(sonardata[i,], debut.E2[i], Pmx.sE2[i], spacing=spacing)
			Area.R.E2[i]<-Area.R.E2[i]+tmp$triangle
			C.R.x.E2[i]<-tmp$cx+tmp$trix
			C.R.y.E2[i]<-tmp$cy+tmp$triy
		}
		if(Flags[i]==2){
			tmp<-tct(sonardata[i,], Pmx.sE2[i], fin.E2[i], spacing=spacing)
			Area.S.E2[i]<-Area.S.E2[i]+tmp$triangle
			Area.T.E2[i]<-Area.R.E2[i]+Area.S.E2[i]
			C.S.x.E2[i]<-tmp$trix+tmp$cx
			C.S.y.E2[i]<-tmp$triy+tmp$cy
			C.T.x.E2[i]<-C.R.x.E2[i]+C.S.x.E2[i]
			C.T.y.E2[i]<-C.R.y.E2[i]+C.S.y.E2[i]
		}
	}
	C.R.x.E1<-C.R.x.E1/Area.R.E1*spacing
	C.R.y.E1<-C.R.y.E1/Area.R.E1	
	C.S.x.E1<-C.S.x.E1/Area.S.E1*spacing
	C.S.y.E1<-C.S.y.E1/Area.S.E1
	C.T.x.E1<-C.T.x.E1/Area.T.E1*spacing
	C.T.y.E1<-C.T.y.E1/Area.T.E1
	C.R.x.E2<-C.R.x.E2/Area.R.E2*spacing
	C.R.y.E2<-C.R.y.E2/Area.R.E2
	C.S.x.E2<-C.S.x.E2/Area.S.E2*spacing
	C.S.y.E2<-C.S.y.E2/Area.S.E2
	C.T.x.E2<-C.T.x.E2/Area.T.E2*spacing
	C.T.y.E2<-C.T.y.E2/Area.T.E2
	Time.S.E1<-(fin.E1-Pmx.sE1)*spacing
	Time.R.E1<-(Pmx.sE1-debut.E1)*spacing
	Time.T.E1<-(fin.E1-debut.E1)*spacing
	Time.S.E2<-(fin.E2-Pmx.sE2)*spacing
	Time.R.E2<-(Pmx.sE2-debut.E2)*spacing
	Time.T.E2<-(fin.E2-debut.E2)*spacing
	xx<-cbind(Area.R.E1, Area.S.E1, Area.T.E1, Area.R.E2, Area.S.E2, Area.T.E2, 
		C.R.x.E1, C.R.y.E1, C.S.x.E1, C.S.y.E1,C.T.x.E1, C.T.y.E1, C.R.x.E2, 
		C.R.y.E2, C.S.x.E2, C.S.y.E2,C.T.x.E2, C.T.y.E2, Time.S.E1, Time.R.E1, 
		Time.T.E1, Time.S.E2, Time.R.E2, Time.T.E2)
	colnames(xx)<-c("Area.R.E1", "Area.S.E1", "Area.T.E1", "Area.R.E2", 
		"Area.S.E2", "Area.T.E2", "C.R.x.E1", "C.R.y.E1", "C.S.x.E1", 
		"C.S.y.E1", "C.T.x.E1", "C.T.y.E1", "C.R.x.E2", "C.R.y.E2", 
		"C.S.x.E2", "C.S.y.E2", "C.T.x.E2", "C.T.y.E2", "Time.S.E1", 
		"Time.R.E1", "Time.T.E1", "Time.S.E2", "Time.R.E2", "Time.T.E2")	
	return(xx)
}

