"extract" <-
function( import.datum=NA, save.data=FALSE, save.plot=FALSE, PathOut=NA, 
	Prefix=NA, show.echoes=FALSE, show.profiles=FALSE, 
	avegroup=1, avesec=FALSE, 
	time.filter=NA, timelaps=13.333, maximumv=14000, pulse=100, 
	tooweak=1000, newspacing=10, reson=25, 
	soundspeed=1500, alt.trigger=0.8, 
	depth.ref=1, nb=5, dateformat="%d-%b-%Y", timesep=":",
	perc.jump=0.001, thresh.high=0.05, thresh.low=0.005, 
	abs.rate.ori=0.2, logf.ori=40, start.gain.ori=6, abs.rate.cor=-0.2, 
	logf.cor=40, start.gain.cor=6, abs.rate.ref=-0.1, logf.ref=0, 
	start.gain.ref=6, expos=2, quiet=TRUE ){

# PROGRAM START
	calll=match.call()
	vvvv<-system.time({
	warnings()
	options(warn=2)
	lct <- Sys.getlocale("LC_TIME")
	Sys.setlocale("LC_TIME", "C")
	
	#### Defines the working list "s"
	if(is.na(import.datum[1]))
		stop("import.datum is a required field\n")
 	s<-list()
	s$timelaps=timelaps/1000000
	s$soundspeed<-soundspeed
	s$pulse=pulse/1000000 
	s$newspacing=newspacing/1000000
	s$imagenex.txt<-import.datum$datum
	import.datum$datum=1
	s$transect.limits<-import.datum$limits
	s$j.refdate<-import.datum$j.refdate
	####Remove the angle parameter not yet implemented	
	s$imagenex.txt<-s$imagenex.txt[,-2]
	
	#### A list of echoes removed throughout the extraction procedure
	s$echo.rem<-list()
	s$groupe<-avegroup
	s$sec<-avesec
	
	if(is.na(abs.rate.cor))
		abs.rate.cor=abs.rate.ori
	if(is.na(start.gain.cor))
		start.gain.cor=start.gain.ori
	if(is.na(logf.cor))
		logf.cor=logf.ori
	s$corr<-list()
	s$corr$abs.rate.ori=abs.rate.ori
	s$corr$logf.ori=logf.ori
	s$corr$start.gain.ori=start.gain.ori
	s$corr$abs.rate.cor=abs.rate.cor
	s$corr$logf.cor=logf.cor 
	s$corr$start.gain.cor= start.gain.cor
	s$corr$abs.rate.ref=abs.rate.ref 
	s$corr$logf.ref=logf.ref 
	s$corr$start.gain.ref=start.gain.ref


	####Output files
	if(length(PathOut)>=1){
		PathOut<-PathOut[1]
	}else{}
	if(is.na(PathOut)){
		save.data<-FALSE
		save.plot<-FALSE
	}else{}
		
	if(save.data==FALSE & save.plot==FALSE){
	#They serve as dummy
		PathOut.data<-"extract.RData"
		PathOut.plot<-"depthnorm.pdf"
	}else{
		if(is.na(Prefix)){
			Prefix<-".TXT"
		}else{
			Prefix<-paste(as.character(Prefix),".TXT",sep="")
		}
		outputdir<-dirname(PathOut)
		outputdir<-paste(outputdir,"_Results",sep="/")
		cat("The output files will be stored in", outputdir, "\n")
		dir.create(outputdir, showWarnings=FALSE)
		PathOut.data<-paste(outputdir, sub(".TXT", "extract.RData", Prefix, 
			ignore.case = TRUE), sep="/")
		PathOut.plot<-paste(outputdir, sub(".TXT", "profile.pdf", 
			Prefix, ignore.case = TRUE), sep="/")
	}
	####Removing echoes which have 0 meter altitude value
	####When the sonar head angle value will be integrated
	####[,3] must be used instead of [,2]
	rem<-which(s$imagenex.txt[,2]==0)
	if(length(rem)!=0){
		s$imagenex.txt<-s$imagenex.txt[-rem,]
	}else{}
	#Intensity values are by default set to 14000 range
	tmp<-max(s$imagenex.txt[,3:length(s$imagenex.txt[1,])])
	s$maximumv=maximumv
	if(tmp>s$maximumv)
		s$maximumv=tmp
	s$imagenex.txt[,3:length(s$imagenex.txt[1,])] <- 
	(s$imagenex.txt[,3:length(s$imagenex.txt[1,])]/s$maximumv)*14000	
	#### Initialize the variables data matrix
	s$sonardata<-s$imagenex.txt[,3:length(s$imagenex.txt[1,])]
	#### Intensity value smoothing
	a<-system.time(s$lisse<-lissagepargroupe(s$sonardata, 21, rem=reson)$lisse)
	a[3]<-sprintf("%.2f", a[3])
	jkl=1
	cat(jkl,"-  Echoes smoothing, completed in", a[3], "sec!\n")
	jkl=jkl+1
		
	ok=1
	while(ok==1){
		s$sonardata<-s$imagenex.txt[,3:length(s$imagenex.txt[1,])]
		s$necho<-nrow(s$sonardata) 	#Nombre of sonar return recorded
		s$lecho<-ncol(s$sonardata)	#Nombre of intensity values per sonar return
		s$datum<-s$imagenex.txt[,1:2]
		colnames(s$datum)<-c("TimeSPM","V.OldAlt")
		#### Find the altitude values
		#maxseuil value; has to be control through function option		
		a<-system.time(tmp<-findalt(lisse=s$lisse, p=alt.trigger, 
			tooweak=tooweak, maxseuil=s$maximumv*0.005, soundspeed=s$soundspeed,
			timelaps=s$timelaps))
		a[3]<-sprintf("%.2f", a[3])
		s$datum<-cbind(s$datum, tmp)
		rem<-which(s$datum[,mn("Flags", mat=s$datum)]<=0)
		if(length(rem)!=0){
			s$echo.rem$badecho2<-rem
			s$sonardata<-s$sonardata[-rem,]
			s$datum<-s$datum[-rem,]
			s$necho<-nrow(s$sonardata)
			rm(tmp)
		}else{
			s$echo.rem$alt2<-NULL
			rm(tmp)
		}
		#"V.NewAlt","P.NewAlt","Flags"
		cat(jkl, "-  Altitude extraction algorythm, completed in",a[3], 
		"sec!\n")
		jkl=jkl+1
		#### Filters the sonar returns based on their altitude of acquisition
		#### Trigger value is controlled through function option		
		a<-system.time(tmp<-altitude.filter(x=s$datum[,mn("TimeSPM", s$datum)], 
			alt=s$datum[,mn("V.NewAlt", s$datum)], trigger=0.6, width=6, 
			height=6, plot.show=TRUE, plot.save=NULL, quiet=TRUE))
		a[3]<-sprintf("%.2f",a[3])
		if(length(tmp$rem)!=0){
			s$echo.rem$alt1<-tmp$rem
			s$sonardata<-s$sonardata[-s$echo.rem$alt1,]
			s$datum<-s$datum[-s$echo.rem$alt1,]
			s$necho<-nrow(s$sonardata) 
			rm(tmp)
		}else{
			s$echo.rem$alt1<-NULL
			rm(tmp)
		}
		cat(jkl, "-  Altitude filtering, completed in",a[3], "sec\n")
		jkl=jkl+1
		#### Corrections for the recording caracteristics
		####
		#### THESE CORRECTIONS ARE SPECIFIC TO OUR SURVEYS
		####
		s$depth.ref<-depth.ref
		a<-system.time(tmp<-correction(sonardata=s$sonardata, 
			oldalt=s$datum[,mn("V.OldAlt", s$datum)], 
			newalt=s$datum[,mn("V.NewAlt", s$datum)], 
			depth.ref=s$depth.ref, s$corr$abs.rate.ori, s$corr$logf.ori, 
			s$corr$start.gain.ori, s$corr$abs.rate.cor, s$corr$logf.cor, 
			s$corr$start.gain.cor, s$corr$abs.rate.ref, s$corr$logf.ref, 
			s$corr$start.gain.ref ))
		a[3]<-sprintf("%.2f", a[3])
		s$sonardata<-tmp$sonardata
		s$ori<-tmp$ori
		rm(tmp)
		cat(jkl, "-  Correction of intensity values, completed in ",a[3],
			" sec!\n")
		jkl=jkl+1
		ijkl=1
		if(show.profiles==TRUE){
			a<-system.time(graph.depthnorm(datum=s$ori, a=NULL, b=NULL, 
				save.plot=save.plot, path= sub(".pdf", 
					paste(ijkl,".pdf",sep=""), PathOut.plot), palet=1, width=9, 
					height=7, title="Raw acoustic returns profile", 	
					timelaps=s$timelaps));
				ijkl=ijkl+1
			a[3]<-sprintf("%.2f", a[3])
			cat(jkl, "-  Depth normalised plot, done. Required time", a[3], 
				"sec.\n")
			jkl=jkl+1
		}
		#### Sonar returns to be remove based on specific times set by the user
		if (!is.na(time.filter)){
			time.filter<-check.file(time.filter)
			tmp<-read.table(time.filter)
			tmp[,2]<-time2spm(tmp[,1], s$j.refdate, dateformat, 
				tmp[,2], timesep)
			tmp[,3]<-time2spm(tmp[,1], s$j.refdate, dateformat, 
				tmp[,3], timesep)
			tmp<-tmp[,-1]	
			a<-system.time(s$echo.rem$visual<-filtre(datum=s$datum, 
			visualrem=tmp))
			a[3]<-sprintf("%.2f", a[3])
			if(!is.null(s$echo.rem$visual)){
				s$sonardata<-s$sonardata[-c(s$echo.rem$visual),]
				s$datum<-s$datum[-c(s$echo.rem$visual),]
			}else{}
			s$necho<-nrow(s$sonardata) 
			rm(tmp)
			cat(jkl, "-  Flagged off specific echoes based on the provided 
			time", " sequences, done!\n")
			jkl=jkl+1
		}else{
			s$echo.rem$visual<-NULL
			cat(jkl, "-  No time sequences was given to flag off 
			unwanted", " echoes, done!\n")
			jkl=jkl+1
		}
		
		#### Depth normalisation procedure : Power correction
		#### The expo value depends on which type of information is recorded
		#### within the sonar acquisition software
		a<-system.time(tmp<-norm.puissance(sonardata=s$sonardata, 
			v.newalt=s$datum[,mn("V.NewAlt", s$datum)], depth.ref=s$depth.ref, 
			expos=expos))
		a[3]<-sprintf("%.2f", a[3])
		s$norm.puis<-tmp$sonardata
		s$datum<-cbind(s$datum, tmp$xx)
		#  6     7
		#"RR1","RR2"
	
		cat(jkl, "-  Power normalization of intensity values, completed in",
			a[3], "sec!\n")
			jkl=jkl+1
		
		if(show.profiles==TRUE){
			a<-system.time(graph.depthnorm(datum=s$norm.puis, a=NULL, b=NULL, 
				save.plot=save.plot, path= sub(".pdf", 
					paste(ijkl,".pdf",sep=""), PathOut.plot), palet=1, width=9, 
					height=7, title="Power normalized acoustic returns profile", 	
					timelaps=s$timelaps)); 
				ijkl=ijkl+1
			a[3]<-sprintf("%.2f", a[3])
			cat(jkl, "-  Depth normalised plot, done. Required time", a[3], 
				"sec.\n")
			jkl=jkl+1
		}
		flush.console()
		if(quiet==FALSE){
			cat("Do you what to change some of the correction parameters?\n",
				"YES=1 or NO=0\n")
			tmp = scan("", nline=1, quiet=TRUE)
			if(length(tmp)==0){
				tmp=0
			}else{}
			if(tmp==1){
				for(i in 1:length(s$corr)){
					cat("\t",names(s$corr)[i], " = ", s$corr[[i]], 
						"; type either a the new value or type nothing! :\n",
						sep="")
					tmp1=scan("",nlines=1,quiet=TRUE)
					if(length(tmp1)!=0){
						s$corr[[i]]=tmp1
					}else{}
				}
			}else{
				tmp=0
			}
			ok=tmp
		}else{
			ok=0
		}
	}
	### Sonar return averaging
	if(s$groupe==0) s$groupe==1
	if(s$groupe!=1 | s$sec==TRUE){
		a<-system.time(tmp<-meanecho(datum=s$datum, sonardata=s$norm.puis, 
			g=s$groupe, sec=s$sec, transect.limits=s$transect.limits))
		a[3]<-sprintf("%.2f", a[3])
		s$datum<-tmp$datum
		s$norm.mean<-tmp$sonardata
		cat(jkl, "-  Sonar return averaging, completed in", a[3], "sec!\n")
		jkl=jkl+1
	}else{
		s$norm.mean<-s$norm.puis
		cat(jkl, "-  Sonar returns averaging was not performed, not asked!\n")
		jkl=jkl+1
	}		

	#### Intensity values smoothing using a moving average
	a<-system.time(tmp0<-lissagepargroupe(s$norm.mean, 21, rem=reson, 
		method="mean"))
	s$lisse<-tmp0$lisse
	a[3]<-sprintf("%.2f", a[3])
	cat(jkl, "-  Smoothing of depth normalized sonar returns, completed in",
		a[3], "sec!\n")
		jkl=jkl+1

	#### Find the true altitude values
#	print(length(tmp0$Pmx.sE))
	a<-system.time(tmp<-findalt(lisse=s$lisse, Pmx.sE=tmp0$Pmx.sE, 
		Vmx.sE=tmp0$Vmx.sE,	p=alt.trigger, soundspeed=s$soundspeed, 
		tooweak=tooweak, timelaps=s$timelaps, maxseuil=s$maximumv*0.005))
	a[3]<-sprintf("%.2f", a[3])
	s$datum<-cbind(s$datum[,c(mn("TimeSPM", s$datum), mn("V.OldAlt", s$datum))],
		tmp, s$datum[,mn("RR", s$datum)])
	rem<-which(s$datum[,mn("Flags",s$datum)]<=0)
#	return(s)
	if(length(rem)!=0){
		s$echo.rem$badecho2<-rem
		s$sonardata<-s$sonardata[-rem,]
		s$lisse<-s$lisse[-rem,]
		s$norm.mean<-s$norm.mean[-rem,]
		s$datum<-s$datum[-rem,]
		s$necho<-nrow(s$sonardata)
		rm(tmp)
	}else{
		s$echo.rem$alt2<-NULL
		rm(tmp)
	}
	colnames(s$datum)<-c("TimeSPM","V.OldAlt","V.NewAlt","P.NewAlt","Flags",
		"RR1","RR2")
	cat(jkl, "-  Altitude extraction algorythm, completed in",a[3], "sec!\n")
	jkl=jkl+1
	#		3				4			5			6		7
	#"V.NewAlt","P.NewAlt","Flags","RR1","RR2"
#	return(s)
	#### Filters the sonar returns based on their altitude of acquisition
	#### Trigger value is controlled through function option		
	a<-system.time(tmp<-altitude.filter(x=s$datum[,mn("TimeSPM", s$datum)], 
		alt=s$datum[,mn("V.NewAlt", s$datum)], trigger=0.6, width=6, height=6, 
		plot.show=TRUE, plot.save=NULL, quiet=TRUE))
	a[3]<-sprintf("%.2f", a[3])
	if(length(tmp$rem)!=0){
		s$echo.rem$alt2<-tmp$rem
		s$sonardata<-s$sonardata[-s$echo.rem$alt2,]
		s$lisse<-s$lisse[-s$echo.rem$alt2,]
		s$norm.mean<-s$norm.mean[-s$echo.rem$alt2,]
		s$datum<-s$datum[-s$echo.rem$alt2,]
		s$necho<-nrow(s$norm.mean) 
		rm(tmp)
	}else{
		s$echo.rem$alt2<-NULL
		rm(tmp)
	}

	cat(jkl, "-  Altitude filtering, completed in", a[3], "sec\n")
	jkl=jkl+1
	
	#### Find the first and second echoes start and end positions
	a<-system.time(tmp<-rechecho(sonardata=s$norm.mean, lisse=s$lisse, 
		P.NewAlt=s$datum[,mn("P.NewAlt", s$datum)], 
		Flags=s$datum[,mn("Flags", s$datum)], rem=reson, perc.jump=perc.jump, 		
		nb=nb, thresh.high=thresh.high, thresh.low=thresh.low, run.max=3, 
		run.mean=21, run.zoom=3))
	a[3]<-sprintf("%.2f", a[3])
	s$datum<-cbind(s$datum, tmp$xx)
	s$E1start<-tmp$E1start
	s$E1end<-tmp$E1end
	ttmp<-colnames(s$datum)
	s$datum[,mn("Flags", s$datum)]<-tmp$Flags
	colnames(s$datum)<-ttmp
	rm(tmp, ttmp)
	#    8       9       10	     11	     12     13      14      15        16	
	# Vmx.sE1 Pmx.sE1  Vmn.sE Pmn.sE  Vmx.sE2 Pmx.sE2 Vmn.sE2 Pmn.sE2 debut.E1
	#   17      18     19  
	# fin.E1 debut.E2 fin.E2 
	#### We can now select sonar returns with either 0, 1 or 2 echoes
	cat(jkl, "-  First and second echo localisation, completed in", a[3],
		"sec!\n")
	jkl=jkl+1
	##### Graph of all intensity values showing the start and end positions of
	##### all echoes
	if(show.profiles==TRUE){
		a<-system.time(graph.depthnorm(datum=s$norm.mean, a=NULL, b=NULL, 
			debut1=s$datum[,mn("debut.E1", s$datum)], 
			fin1=s$datum[,mn("fin.E1", s$datum)], 
			debut2=s$datum[,mn("debut.E2", s$datum)], 
			fin2=s$datum[,mn("fin.E2", s$datum)], 
			save.plot=save.plot, path=PathOut.plot, palet=1, width=9, height=7, 	
			title="Power normalized acoustic returns profile", 	
			timelaps=s$timelaps))
		a[3]<-sprintf("%.2f", a[3])
		cat(jkl, "-  Depth normalised plot, done. Required time", a[3], 
			"sec.\n")
		jkl=jkl+1
	}
	if(show.echoes==TRUE){
		for(j in seq(1, nrow(s$norm.mean), by=2)){
			cat("Press enter to pursue visual analysis or any other keys",
				" if you want to stop\n")
			plot(1:ncol(s$norm.mean), s$norm.mean[j,], "l", col="red", 
				xlim=c(1, 2000), main=j)
			col="darkred"
			if(!is.na(s$datum[j,mn("debut.E1", s$datum)])){
				abline(v = s$datum[j,mn("debut.E1", s$datum)], lty = 1, col=col,
				lwd=2)
			}
			if(!is.na(s$datum[j,mn("fin.E1", s$datum)])){
				abline(v = s$datum[j,mn("fin.E1", s$datum)], lty = 1, col=col, 
				lwd=2)
			}
			if(!is.na(s$datum[j,mn("debut.E2", s$datum)])){
				abline(v = s$datum[j,mn("debut.E2", s$datum)], lty = 1, col=col, 
				lwd=2)
			}
			if(!is.na(s$datum[j,mn("fin.E2", s$datum)])){
				abline(v = s$datum[j,mn("fin.E2", s$datum)], lty = 1, col=col, 
				lwd=2)
			}
			#if(!is.na(s$E1start)){
			#	abline(h = s$E1start, lty = 1, col="blue", lwd=2)
			#}
			#if(!is.na(s$E1end)){
			#	abline(h = s$E1end, lty = 1, col="green", lwd=2)
			#}
			tg<-scan("", what="raw", nlines=1) 
			if(length(tg)!=0)
				break
		}
	}
	
	#### Depth normalization : Temporal Correction
	a<-system.time(tmp<-norm.temporal(norm.puis=s$norm.mean, 
		newspacing=s$newspacing, timelaps=s$timelaps, depth.ref=s$depth.ref, 
		NewAlt=s$datum[,mn("V.NewAlt", s$datum)]))
	a[3]<-sprintf("%.2f", a[3])
	s$norm.temp<-tmp$norm.temp
	tmp0<-colnames(s$datum)
	s$datum<-cbind(s$datum, tmp$TimeCorE1, tmp$TimeCorE2)
	#								20			21
	colnames(s$datum)<-c(tmp0, "TimeCorE1", "TimeCorE2")
	rm(tmp0)
	cat(jkl, "-  Sonar returns temporal normalization, completed in", a[3], 
		"sec!\n")
	jkl=jkl+1

	a<-system.time(tmp<-TimeNormAdj(datum=s$datum, 
		TimeCorE=s$datum[,mn("TimeCorE1", s$datum)], timelaps=s$timelaps, 
		spacing=s$newspacing, what=c("P.NewAlt", "Pmx.sE1", "Pmn.sE", 
		"Pmx.sE2", "Pmn.sE2", "debut.E1", "fin.E1", "debut.E2", "fin.E2")))
	a[3]<-sprintf("%.2f", a[3])
	s$datum<-tmp
	cat(jkl, "-  Temporal corrections applied on diverse marker found in every",
		" echoes, completed in", a[3], "sec!\n")
	jkl=jkl+1

	#### The definition of FLAGS variable value	
	#	FLAG=0.5	First echo rise area
	#	FLAG=1		First echo complete area											
	#	FLAG=1.5	First echo complete and second echo rise areas
	#	FLAG=2		Both first and second echoes complete area
	#	FLAG=0		No echo found or erroneous

	### Remove ambinat noise
	a<-system.time(s$norm.noise<-rmnoise(sonardata=s$norm.temp, 
		debut1=s$datum[,mn("debut.E1", s$datum)], 
		Flags=s$datum[,mn("Flags", s$datum)]))
	a[3]<-sprintf("%.2f", a[3])
	cat(jkl, "-  Ambiant noise removal, completed in", a[3], "sec!\n")
	jkl=jkl+1
	#print(levels(as.factor(s$datum[,5])))(s)
	
	#### Extraction of VE variablse, Variable Extracted
	#### Extraction of centroids, area and some temporal values	
	a<-system.time(tmp<-area.centroid.time(sonardata=s$norm.noise,  
	debut.E1=s$datum[,mn("debut.E1", s$datum)], 
	fin.E1=s$datum[,mn("fin.E1", s$datum)], 
	debut.E2=s$datum[,mn("debut.E2", s$datum)], 
	fin.E2=s$datum[,mn("fin.E2", s$datum)], 
	Pmx.sE1=s$datum[, mn("Pmx.sE1",s$datum)], 
	Pmx.sE2=s$datum[,mn("Pmx.sE2", s$datum)], 
	Flags=s$datum[,mn("Flags", s$datum)], spacing=s$newspacing))
	a[3]<-sprintf("%.2f", a[3])
	s$datum<-cbind(s$datum, tmp)
	# Area.R.E1	Area.S.E1	Area.T.E1	Area.R.E1	Area.S.E1	Area.T.E2	
	# C.R.x.E1	C.R.y.E1	C.S.x.E1	C.S.y.E1 	C.T.x.E1	C.T.y.E1	
	# C.R.x.E2	C.R.y.E2	C.S.x.E2	C.S.y.E2 	C.T.x.E2	C.T.y.E2	
	# Time.S.E1	Time.R.E1	Time.T.E1	Time.S.E2	Time.R.E2	Time.T.E2
	cat(jkl, "-  Extraction of echoes areas, centroids, and temporal values,",
		" completed in", a[3], "sec!\n")
	jkl=jkl+1

	#### Extraction of the first echo from all sonar returns
	a<-system.time(tmp<-echoextract(sonardata=s$norm.noise, 
		debut=s$datum[,mn("debut.E1", s$datum)], 
		fin=s$datum[,mn("fin.E1", s$datum)], 
		Flags=s$datum[,mn("Flags", s$datum)]))
	a[3]<-sprintf("%.2f", a[3])
	s$normecho1<-tmp;rm(tmp)
	cat(jkl, "-  First echoes extraction, completed in", a[3], "sec!\n")
	jkl=jkl+1

	#### Statistical momments 
	a<-system.time(tmp<-moments(datum=s$normecho1, 
		Flags=s$datum[,mn("Flags", s$datum)]))
	a[3]<-sprintf("%.2f", a[3])
	s$datum<-cbind(s$datum,	tmp);rm(tmp)
	# Ave.E1 Var.E1 Sdev.E1 Skew.E1 Kurt.E1
	cat(jkl, "-  Extraction of statistical moments, completed in", a[3], "sec!\n")
	jkl=jkl+1
	
	#### Area fractions
	a<-system.time(tmp<-airefraction(sonardata=s$normecho1, 
		Flags=s$datum[,mn("Flags", s$datum)], spacing=s$newspacing))
	a[3]<-sprintf("%.2f", a[3])
	s$datum<-cbind(s$datum,	tmp);rm(tmp)
	# "f1.16", ... f15.16
	cat(jkl, "-  Extraction of cummalative power fraction, completed in", a[3], 
		"sec!\n")
	jkl=jkl+1

	#### Histogram values 
	#n must be a integer
	a<-system.time(tmp<-histo(sonardata=s$normecho1, 
		Flags=s$datum[,mn("Flags", s$datum)], n=7))
	a[3]<-sprintf("%.2f", a[3])
	s$datum<-cbind(s$datum, tmp);rm(tmp)		
	#   54   +n=  61
	# Histo1 ... Histo7
	cat(jkl, "-  Extraction of power histogram, completed in",a[3], "sec!\n")
	jkl=jkl+1

	#### Variable gestion and creation
	a<-system.time(tmp<-variable(datum=s$datum, normecho1=s$normecho1, 
		lisse=s$lisse))
	a[3]<-sprintf("%.2f", a[3])
	s$VE<-tmp$VE
	s$VI<-tmp$VI
	cat(jkl, "-  Creation of VE and VI matrices, completed in", a[3], "sec!\n")
	jkl=jkl+1

	#### Time adjustements and output file printing
	s$datetime<-spm2time(s$VE[,1], s$j.refdate, timesep)
	tmp<-c("Date","Times",colnames(s$VE)[-1])
	s$VE<-cbind(as.character(s$datetime$date), s$datetime$times, s$VE[,-1])
	rownames(s$VE)<-NULL
	colnames(s$VE)<-tmp
	
	tmp<-c("Date","Times",colnames(s$VI)[-1])
	s$VI<-cbind(as.character(s$datetime$date), s$datetime$times, s$VI[,-1])
	rownames(s$VI)<-NULL
	colnames(s$VI)<-tmp
	
#	extract.data<-list(VE=s$VE, VI=s$VI, ori=s$ori, norm.mean=s$norm.mean, 
#		call=calll)
	extract.data<-list(VE=s$VE, VI=s$VI, call=calll)
	
#	a<-system.time(write.table(s$VE,file=FileVE))
#	a[3]<-sprintf("%.2f",a[3])
#	cat(jkl, "-  Writing of VE matrix, completed in",a[3], "sec!\n")
#	jkl=jkl+1

#	a<-system.time(write.table(s$VI,file=FileVI))
#	a[3]<-sprintf("%.2f",a[3])
#	cat(jkl, "-  Writing of VI matrix, completed in",a[3], "sec!\n")
#	jkl=jkl+1
	if(save.data==TRUE){
		a<-system.time(save(extract.data,file=PathOut.data, compress=TRUE))
		a[3]<-sprintf("%.2f",a[3])
		cat(jkl, "-  The working list 's' was save in",a[3], "sec!\n")
		jkl=jkl+1
		cat("Save done\n")
	}else{}
	})
	vvvv[3]<-sprintf("%.2f",vvvv[3]/60) 
	print(paste("Total time required ", vvvv[3]," min."), seq="")
	Sys.setlocale("LC_TIME", lct)
	return(extract.data)
#	return(s)
}

