"findalt" <-
function(lisse, p=0.8, Vmx.sE=NULL, Pmx.sE=NULL, soundspeed=1500, 
	tooweak=150, timelaps=13.333/1000000, maxseuil=14000*0.005, head.lim=1) {
	
# DESCRIPTION

# This function estimate from the signal shapes the altitude of acquisition

# INPUT

# lisse			Is a smoothed matrix of the sonar intensity values 
#				(without time, angle alt and so forth )
# p 			Is the threshold that find the altitude point.
#				The default is 0.8.
#				It stends for percentage of the maximum value found in 
#				the signal.
# soundspeed 	Is the speed of sound at the site in meters per seconds.
# timelaps		Is the time fraction found between every intensity values found
#				in one recorded signal in seconds.
# maxseuil		The point where the altitude is found must be higher than that 
#				value
# tooweak 		If the signal does not have maximum peak stronger than this 
#				value the signal will be use in the analysis
# Vmx.sE		The signal maximum value
# Pmx.sE		The signal point of maximum value
# head.lim		The distance between the sonar head and the ROV skids
#				This limits makes sure even if a sonar return has been sampled 
#				at altitude lower than 1 meter, the signal will be removed,
#				because it is physically impossible

	lecho<-ncol(lisse)
	necho<-nrow(lisse)
	#### If not given, we find the the point of maximum
	if(is.null(Vmx.sE))
		Vmx.sE<-apply(lisse, 1, max, na.rm=TRUE)
	if(is.null(Pmx.sE))
		Pmx.sE<-apply(lisse, 1, which.max)
	
	#### Create a vector describing each sonar return
	Flags<-rep(2, necho)
	
	tmp<-which(Vmx.sE<=tooweak)
	if(length(tmp)!=0)
		Flags[tmp]<--1
	#library(datasets)
	falt<-Vmx.sE*p
	#### Equivalent for one meters of altitude
	P.NewAlt<-rep(NA, necho)
	use<-which(Flags!=-1)
	for (j in use){
		if(Flags[j]!=0){
			##### Finds NewAlt position
			res<-which(lisse[j,Pmx.sE[j]:1]<=falt[j])
			if(length(res)!=0){
				P.NewAlt[j]<-Pmx.sE[j]-min(res, na.rm=TRUE)+1
				# Stop the search and keep the preexisting value
				if (lecho-P.NewAlt[j]<100){
					tmp<-which(lisse[j,Pmx.sE[j]:lecho]<=maxseuil)
					if(length(tmp)!=0){
						Flags[j]<-1
					}else{
						Flags[j]<--1	
						#### We do not have a complete first echo
					}
				}else{}
			}else{
				Flags[j]<--1
			}
		}else{}
	}
	NewAlt<-(P.NewAlt/2)*soundspeed*timelaps
	
	#### Head position limits versus skids
	tmp<-which(NewAlt<head.lim)
	if(length(tmp)!=0)
		Flags[tmp]<--1
	xx<-cbind(NewAlt, P.NewAlt, Flags) 
	colnames(xx)<-c("V.NewAlt", "P.NewAlt", "Flags")
	return(xx)
}

