"import.imatxt" <-
function(path=NA, number.file=NA, echolength=NA, limits=NA, dateformat="%d-%b-%Y", timesep=":", remove.all=TRUE, see=TRUE){
	
# DESCRIPTION

# Import either one or multiple successive imagenex .TXT files

# INPUT

# Filepath 		A vector of paths "~/... imagenex file.txt converted from .81b
#				The default is NA. File will be asked.			
# number.file 	How many files to select if no Filepath have been specified.
#				The default is 1.
# echolength 	How long or how many intensity values constitute one echo.
#				Default is NA

# OUTPUT

#Returns the corrected imagenex.txt and the files paths
	lct <- Sys.getlocale("LC_TIME")
	Sys.setlocale("LC_TIME", "C")
	
	if(is.na(echolength))
		stop("Please provide a value for echolength")
	if(!is.na(path[1])){
		number.file=length(path)
		path<-check.file(path)	
	}else{
		path<-rep(NA, number.file)
		path<-check.file(path)
	}
	
	# DATA importation 
 	#Keeping: time, acquisition angle, altitude, sonar intensity*echolength
	
	limits0<-matrix(NA, number.file, 5)
	for (i in 1:number.file){
		tmp<-scan(path[i], what="character", quiet=TRUE)
		tmp<-t(matrix(tmp, ncol=length(tmp)/(echolength+9)))
		tmp<-tmp[,-c(1, 4:7)] #8 is the angle value
		limits0[i,]<-c(basename(path[i]),tmp[1,1:2], tmp[nrow(tmp),1:2])	
		if(i!=1){
			datum<-rbind(datum,tmp)
		}else{
			datum<-tmp
		}
	}	
	#Compute the date of reference based on the earlier date found or on the user  setting	
	j.refdate<-min(as.numeric(as.Date(datum[,1],dateformat)))
	
	#Defines if the user has given a path to a file describing the transects limits
	if(is.na(limits)){
		limits<-limits0
	}else{
		limits<-check.file(limits,quiet=FALSE)
		limits<-read.table(limits)
	}
	limits[,2]<-time2spm(limits[,2], j.refdate, dateformat, limits[,3], timesep)
	limits[,3]<-time2spm(limits[,4], j.refdate, dateformat, limits[,5], timesep)
	limits<-limits[,-c(4,5)]
	#Convert Date and Time column into TimeSPM
	datum[,2]<-time2spm(datum[,1], j.refdate, dateformat, datum[,2], timesep)
	datum<-matrix(as.numeric(datum[,-1]), ncol=echolength+3)
	#Verify the times integrity
	datum<-timeCheck(datum, limits, j.refdate, remove.all, see)
	Sys.setlocale("LC_TIME", lct)
	return(list(datum=datum, limits=limits, j.refdate=j.refdate, path=path))
}

