"lissagepargroupe" <-
function(datum, g, method = c("max", "mean", "median"), 
	rem=NULL) {

# DEFINITION

# Moving average of 'g' consecutive intensity values in a sonar return  
# It uses three methods: max, mean or median

# INPUT

# datum			The data on which to perform the transformation
# g				The width of the moving window
# method 		The method used on the moving window, max, mean or median		
# Rem 			The number of intensity values that we should not consider at 
#				the	beginning of each echo recordings

# NOTES

# All NA values are excluded during computation and are all replaced afterwards
# Cette algortyhme fontinonne aussi pour les vecteurs
	
#	library(zoo)
	if(is.vector(datum)){
		Vmx.sE<-NA
		Pmx.sE<-NA
		nc<-length(datum)
		if(!is.null(rem))
			datum[1:rem]<-NA
		mrk<-which(!is.na(datum))
		datum[mrk] <- switch(match.arg(method), 
			max = {
        		runningfilter(datum[mrk],g,"max")
       		},
       		mean = {
				runningfilter(datum[mrk],g,"mean")
       		}, 
       		median = {
				runningfilter(datum[mrk],g,"median")
       		},
       		min = {
				runningfilter(datum[mrk],g,"min")
       		}
       	)
       	datum<-round(datum)
	 	if(any(!is.na(datum))){
		 	Vmx.sE<-max(datum, na.rm=TRUE)
			Pmx.sE<-which.max(datum)
		}else{}	
	}	
	if(is.matrix(datum)){
	 	nr=nrow(datum)
	 	nc=ncol(datum)
	 	Vmx.sE<-rep(NA, nr)
		Pmx.sE<-rep(NA, nr)
		mrk=0;
	 	if(!is.null(rem)){
			datum[,1:rem]<-NA
			if(any(is.na(datum[,((rem+1):nc)]))) mrk=1
		}else{
			if(any(is.na(datum))) mrk=1
		}
		if(mrk==1){ # Traite chaque row comme un vecteur
			for(i in 1:nr){
				mrk<-which(!is.na(datum[i,]))
				datum[i,mrk] <- switch(match.arg(method), 
					max = {
       			 		runningfilter(datum[i,mrk],g,"max")
       				},
      	 			mean = {
						runningfilter(datum[i,mrk],g,"mean")
	       			}, 
    	   			median = {
						runningfilter(datum[i,mrk],g,"median")
       				},
       				min = {
						runningfilter(datum[i,mrk],g,"min")
      	 			}
      	 		)				
			}
			for(i in 1:nr){
		 		if(any(!is.na(datum[i,]))){
					Vmx.sE[i]<-max(datum[i,], na.rm=TRUE)
					Pmx.sE[i]<-which.max(datum[i,])
				}else{}
			}		
		}else{
			if(!is.null(rem)){
				datum<-datum[,-(1:rem)]
			}else{}
			datum<- switch(match.arg(method), 
				max = {
        			runningfilter(datum,g,"max")
       			},
       			mean = {
					runningfilter(datum,g,"mean")
       			}, 
       			median = {
					runningfilter(datum,g,"median")
       			},
       			min = {
					runningfilter(datum,g,"min")
       			}
       		)
       		datum<-round(datum)
       		Vmx.sE<-apply(datum, 1, max, na.rm=TRUE)
			Pmx.sE<-apply(datum, 1, which.max)
			if(!is.null(rem)){ 
				datum<-cbind(matrix(NA,nr,rem),datum)
				Pmx.sE<-Pmx.sE+rem	
			}
		}
	}else{}
	return(list(lisse=datum, Vmx.sE=Vmx.sE, Pmx.sE=Pmx.sE))
}

