"norm.puissance" <-
function(sonardata, v.newalt, depth.ref=1, expos=2){ 

# DEFINITION

# We are applying the correction for spherical spreading
# based on Hamilton pupblications Hamilton, 2001

# INPUT

# sonardata		The data matrix containing the sonar return intensity
# v.newalt		The altitude value in meters that we have computed
# depth.ref		The depth reference at which we which to normalise 
#				every sonar return
# expos			This exposant can be modifyied, it will be helpful to modify it
#				when another type of sonar information will be recorded.
#				See Hamilton, 2001

# OUTPUT

# The output is a list: 
# sonardata		The power corrected sonardata
# xx			The value used to correct the original data matrix

	rr<-(v.newalt/depth.ref)^(expos)
	rr2<-(v.newalt*2/depth.ref*2)^(expos)	
	sonardata<-sonardata*rr
	xx<-cbind(rr, rr2)
	colnames(xx)<-c("RR1", "RR2")
	return(list(sonardata=sonardata, xx=xx))
}

