"probFrda" <-
function(Y,X,n,p,m,q,nperm,projX,projW,projXW,SS.Y,SS.Yfit.X,covar,
                     SS.Yfit.XW,print.res=TRUE)
# This function carries out a permutation test for the bimultivariate R-square 
# coefficient by permutation of the raw data if there are no covariables, or
# by permutation of the residuals of the null model in the presence of covariables.
# Reference: Numerical Ecology, Chapter 11 (Legendre & Legendre 1998)
#
# SS.Y = SS of Y
# SS.Yfit.X = SS of fitted values of f(Y|X)
# SS.Yfit.XW = SS of fitted values of f(Y|(X+W))
# 
{
	df1=m
	df2=n-m-q-1
	if(covar==FALSE) {
	#	cat('Debug:  SS.Y =',SS.Y,'  SS.Yfit.X =',SS.Yfit.X,'\n')
		Fref=(SS.Yfit.X*df2)/((SS.Y-SS.Yfit.X)*df1)
	}
	else {
	# cat('Debug: SS.Y =',SS.Y,' SS.Yfit.X =',SS.Yfit.X,' SS.Yfit.XW =',SS.Yfit.XW,'\n')
		Fref=(SS.Yfit.X*df2)/((SS.Y-SS.Yfit.XW)*df1)
		Yfit.W = projW %*% Y
		Yres.W = Y - Yfit.W
	}
	nPGE=1
	vec=c(1:n)
	if(covar==FALSE) {
		if(print.res==TRUE) 
			cat('\n','Test results, permutation of raw data Y','\n',sep="")
		for(i in 1:nperm)
 	  	{
 		# YPerm = Y[sample(vec,n),]
	  	YhatPerm = projX %*% Y[sample(vec,n),]
	  	SS.YhatPerm = sum(YhatPerm*YhatPerm)
 	  	Fper=(SS.YhatPerm*df2)/((SS.Y-SS.YhatPerm)*df1)
 	  	if(Fper >= Fref) nPGE=nPGE+1
  	  	}
  	  }
  	  else {
		if(print.res==TRUE) 
			cat('\n','Test results, permutation of residuals of null model','\n',sep="")
		for(i in 1:nperm)
 	  	{
 		Yperm = Yfit.W + Yres.W[sample(vec,n),]
 		Yperm.hat.W = projW %*% Yperm
 		Yperm.hat.XW = projXW %*% Yperm
 		SS.Yperm.hat.W = sum(Yperm.hat.W*Yperm.hat.W)
 		SS.Yperm.hat.XW = sum(Yperm.hat.XW*Yperm.hat.XW)
 	  	Fper=((SS.Yperm.hat.XW - SS.Yperm.hat.W) * df2)/((SS.Y - SS.Yperm.hat.XW) * df1)
 	  	if(Fper >= Fref) nPGE=nPGE+1
  	  	}
  	  }
	P=nPGE/(nperm+1)
	if(print.res==TRUE)
		cat('F =',Fref,'  Prob(',nperm,'permutations) =',P,'\n')
	return(list(F=Fref,nperm=nperm,Prob=P))
}

