"rechecho" <-
function(sonardata, lisse, P.NewAlt, Flags, rem, perc.jump=0.001, 
	thresh.high=0.05, thresh.low=0.005, run.max=3, run.mean=21, run.zoom=3, 
	nb=4){
	
	
# DESCRIPTION

# This function aims to find the exact location of the beginning and ending 
# position of both the first and second echoes
# We find inflection points of each sonar return
# We estimate its variance and based on these values we are looking for a serie
# of intensity values that goes beyond that variance value

# INPUT

# sonardata			The sonar return data matrix
# lisse				The smoothed sonar return data matrix
# P.NewAlt			The position of the altitude value found in every returns
# Flags				The values stating is the returns has one or two echoes
# rem				The nomber of first intensity value not to be considered 
#					in the search
# perc.jump=0.001   The amount of incrementation the serie of intensity value
#					must have. This value is multiplied by the echo maximum value 
# thresh.high=0.05  See echostartend function for a definition
# thresh.low=0.005	See echostartend function for a definition
# run.max=3			The width of the moving window used
# run.mean=21		The width of the moving window used
# run.zoom=3		The width of the moving window used
# nb=4				See echostartend function for a definition

# OUTPUT

	library(datasets)
	
	#### Step 1: Find the first echo
	####	First echo found 					=	FLAG 1
	####    First and second echo found 		=	FLAG 2
	####	First and second echo rise			=	FLAG 1.5
	####	First echo is incomplete or missing	=	FLAG 0
	
	#### Defines the limits of the search for E1 (first echo)
	necho<-nrow(sonardata)
	lecho<-ncol(sonardata)
	#### Find the first limit
	limE1<-P.NewAlt-lecho*0.10
	limE1[limE1<rem]<-rem
	
	#### Initialization of vectors and matrices
	tmp<-rep(NA, necho)
	
	limf2<-tmp;
	debut.E1<-tmp; fin.E1<- tmp;debut.E2<- tmp;fin.E2<- tmp;
	Pmx.sE1<-tmp; Pmn.sE1<-tmp;Pmx.sE2<- tmp; Pmn.sE2<-tmp
	Vmx.sE1<-tmp; Vmn.sE1<-tmp;Vmx.sE2<- tmp;  Vmn.sE2<-tmp
	limE2<-tmp
	
	#### The flags have been initiallised and prefiltered in findalt.R
	
	#### Create the smoothed matrices allowing E1 search
	
	#### The use of both methods create a nice curve, round and smooth
	#### Doing so we minimize the impact of erratic depression within the echoes
#	cat("\tBeginning of smoothing\n")
	r.max<-lissagepargroupe(sonardata, run.max, rem=rem, method="max")
	r.mean<-lissagepargroupe(r.max$lisse, run.mean, rem=rem, method="mean")
	rm(r.max)
	r.mean2<-ceiling((run.mean+run.max)/2)
	r.zoom2<-ceiling(run.zoom/2)
	r.zoom<-lissagepargroupe(sonardata, run.zoom, rem=rem, method="mean")
#	cat("\tEnd of smoothing\n")
	
	Pmx.sE1<-apply(r.mean$lisse, 1, which.max)
	lim<-Pmx.sE1+r.mean2
	lim[lim>=lecho]<-lecho
	for(i in 1:necho){
	#### Find Pmx.sE1 and Vmx.sE1
		Pmx.sE1[i]<-(Pmx.sE1[i]-r.mean2)+
			which.max(r.zoom$lisse[i,(Pmx.sE1[i]-r.mean2):(lim[i])])-1
		Vmx.sE1[i]<-r.zoom$lisse[i,Pmx.sE1[i]]
		limE2[i]<-Pmx.sE1[i]*3
		if(limE2[i]>lecho)
			limE2[i]<-lecho
		if((P.NewAlt[i]*2+25)>lecho){
			Flags[i]<-1.5
			limf2[i]<-lecho
		}else{
			limf2[i]<-P.NewAlt[i]*2
		}
		
	#### Find Pmn.sE1 and Vmn.sE1
		Pmn.sE1[i]<-which.min(r.mean$lisse[i,Pmx.sE1[i]:limf2[i]])+Pmx.sE1[i]-1
		lim[i]<-Pmn.sE1[i]+r.mean2
		if(lim[i]>=lecho){
			lim[i]<-lecho
			Flags[i]<-1
		}else{}
		Pmn.sE1[i]<-(Pmn.sE1[i]-r.mean2)+
			which.min(r.zoom$lisse[i,(Pmn.sE1[i]-r.mean2):lim[i]])-1
		Vmn.sE1[i]<-r.zoom$lisse[i,Pmn.sE1[i]]

	#### Trouve Pmx.sE2 et Vmx.sE2
		if(Flags[i]>1){			
			Pmx.sE2[i]<-which.max(r.mean$lisse[i,Pmn.sE1[i]:limE2[i]])+
				Pmn.sE1[i]-1
			#### Find real E min location
			lim[i]<-Pmx.sE2[i]+r.mean2
			if(lim[i]>=lecho)
				lim[i]<-lecho
			Pmx.sE2[i]<-(Pmx.sE2[i]-r.mean2)+
				which.max(r.zoom$lisse[i,(Pmx.sE2[i]-r.mean2):lim[i]])-1
			lim[i]<-Pmx.sE2[i]+r.mean2
			if(lim[i]>=lecho)
				lim[i]<-lecho
			Pmx.sE2[i]<-(Pmx.sE2[i]-r.zoom2)+
				which.max(sonardata[i,(Pmx.sE2[i]-r.zoom2):lim[i]])-1
			Vmx.sE2[i]<-r.zoom$lisse[i,Pmx.sE2[i]]
		}else{}
		if(Flags[i]>1.5){			
			Pmn.sE2[i]<-which.min(r.mean$lisse[i,Pmx.sE2[i]:limE2[i]])+
				Pmx.sE2[i]-1
			lim[i]<-Pmn.sE2[i]+r.mean2
			if(lim[i]>=lecho){
				lim[i]<-lecho
			}else{}
			Pmn.sE2[i]<-(Pmn.sE2[i]-r.mean2)+
				which.min(r.zoom$lisse[i,(Pmn.sE2[i]-r.mean2):lim[i]])-1
			Vmn.sE2[i]<-r.zoom$lisse[i,Pmn.sE2[i]]
		}else{}
		
	}
	
	tmpmat.d.E1<-matrix(NA, necho, lecho)
	tmpmat.f.E1<-matrix(NA, necho, lecho)
	tmpmat.d.E2<-matrix(NA, necho, lecho)
	tmpmat.f.E2<-matrix(NA, necho, lecho)
	max.jump=(median(Vmx.sE1, na.rm = TRUE)+2*sd(Vmx.sE1, na.rm = TRUE))*perc.jump

#### StartE1 noise level	

	use<-which(Flags>0.5)
	for(i in use){
		tmpmat.d.E1[i,limE1[i]:Pmx.sE1[i]]<-1
	}	
	a<-system.time(tmp0<-echostartend(tmpmat.d.E1*r.mean$lisse, max.jump=max.jump, nb=nb, 
		thresh.high=thresh.high, thresh.low=thresh.low, debut=TRUE, fin=FALSE))[3]
	print(a)
	debut.E1=tmp0$Debut.E
	tmppp<-length(which(!is.na(debut.E1)))
	cat("\t",tmppp, " first echo starts found : \t", 
		round(( tmppp/length(debut.E1))*100, digit=2),"%\n",sep="")
	sdPmean<-rep(NA, necho)
	#### Find the noise value association to the beginning
	use<-which(!is.na(tmp0$Debut.E))
	for(i in use){
		sdPmean[i]<-2*sd(r.mean$lisse[i, rem:tmp0$Debut.E[i]], na.rm = TRUE)+
			mean(r.mean$lisse[i,rem:tmp0$Debut.E[i]], na.rm = TRUE)
	}
	StartE1<-mean(sdPmean, na.rm = TRUE)+sd(sdPmean, na.rm = TRUE)		

##### EndE1 noise level	

	use<-which(Flags>0.5)
	for(i in use){
		tmpmat.f.E1[i,Pmx.sE1[i]:Pmn.sE1[i]]<-1
	}
	tmp0<-echostartend(tmpmat.f.E1*r.mean$lisse, max.jump=max.jump, nb=nb, 
		thresh.high=thresh.high, thresh.low=thresh.low, debut=FALSE, fin=TRUE)
	fin.E1=tmp0$Fin.E
	tmppp<-length(which(!is.na(fin.E1)))
	cat("\t",tmppp, " first echo ends found : \t", 
		round(( tmppp/length(fin.E1))*100, digit=2),"%\n",sep="")
	sdPmean<-rep(NA, necho)
	use<-which(!is.na(tmp0$Fin.E))
	for(i in use){
		sdPmean[i]<-2*sd(r.mean$lisse[i,Pmn.sE1[i]:tmp0$Fin.E[i]],na.rm = TRUE)+
			mean(r.mean$lisse[i,Pmn.sE1[i]:tmp0$Fin.E[i]], na.rm = TRUE)
	}
	EndE1<-mean(sdPmean, na.rm = TRUE)+sd(sdPmean, na.rm = TRUE)		

#### StartE2 noise level
	max.jump=(median(Vmx.sE2, na.rm = TRUE)+2*sd(Vmx.sE2, na.rm = TRUE))*perc.jump
	use<-which(Flags>1)
#	print(use)
	for(i in use){
		tmpmat.d.E2[i,Pmn.sE1[i]:Pmx.sE2[i]]<-1
	}
#	print((tmpmat.d.E2*r.mean$lisse)[1,])
	
	tmp0<-echostartend(tmpmat.d.E2*r.mean$lisse, max.jump=max.jump, nb=nb, 
		thresh.high=thresh.high, thresh.low=thresh.low, debut=TRUE, fin=FALSE)
#	print(debut.E2)
	debut.E2=tmp0$Debut.E
	tmppp<-length(which(!is.na(debut.E2)))
	cat("\t",tmppp, " second echo starts found : \t", 
		round(( tmppp/length(debut.E2))*100, digit=2),"%\n", sep="")
	sdPmean<-rep(NA, necho)
	use<-which(!is.na(tmp0$Debut.E))
	for(i in use){
		sdPmean[i]<-2*sd(r.mean$lisse[i,Pmn.sE1[i]:tmp0$Debut.E[i]],na.rm=TRUE)+
		mean(r.mean$lisse[i,Pmn.sE1[i]:tmp0$Debut.E[i]], na.rm = TRUE)
	}
	StartE2<-mean(sdPmean, na.rm = TRUE)	

#### EndE2 noise level

	use<-which(Flags>1.5)	
	for(i in use){
		tmpmat.f.E2[i,Pmx.sE2[i]:Pmn.sE2[i]]<-1
	}	
	tmp0<-echostartend(tmpmat.f.E2*r.mean$lisse, max.jump=max.jump, nb=nb, 
		thresh.high=thresh.high, thresh.low=thresh.low, debut=FALSE, fin=TRUE)
	fin.E2=tmp0$Fin.E
	tmppp<-length(which(!is.na(fin.E2)))
	cat("\t",tmppp, " second echo ends found : \t", 
		round(( tmppp/length(fin.E2))*100, digit=2),"%\n",sep="")
	sdPmean<-rep(NA, necho)
	use<-which(!is.na(tmp0$Fin.E))
	for(i in use){
		sdPmean[i]<-2*sd(r.mean$lisse[i,Pmn.sE2[i]:tmp0$Fin.E[i]], na.rm=TRUE)+
		mean(r.mean$lisse[i,Pmn.sE2[i]:tmp0$Fin.E[i]], na.rm = TRUE)
	}
	EndE2<-mean(sdPmean, na.rm = TRUE)	

# Trouve le dbut de l'echo1

	for(i in 1:necho){
		tmp<-(which(r.mean$lisse[i,limE1[i]:Pmx.sE1[i]]<=StartE1))
		if(length(tmp!=0)){
			debut.E1[i]<-limE1[i]+max(tmp, na.rm=TRUE)-1
		}else{
			Flags[i]<-0
		}
		if(!is.na(debut.E1[i])){
			debut.E1[i]<-(debut.E1[i]-r.mean2)+
			which.min(r.zoom$lisse[i,(debut.E1[i]-r.mean2):(debut.E1[i])])-1
			debut.E1[i]<-(debut.E1[i]-r.zoom2)+which.min(
				sonardata[i,(debut.E1[i]-r.zoom2):(debut.E1[i]+r.zoom2)])-1
		}else{}
	}
	tmp<-which(debut.E1*2>=lecho)
	if(length(tmp)!=0)
		Flags[tmp]<-1

#### Trouve la fin l'echo1

	for(i in which(Flags>=1)){
		tmp<-(which(r.mean$lisse[i,Pmx.sE1[i]:Pmn.sE1[i]]<=EndE1))
		if(length(tmp!=0)){
			fin.E1[i]<-Pmx.sE1[i]+min(tmp, na.rm=TRUE)-1
		}else{
			#	Flags[i]<-0.5
		}
		lim<-fin.E1[i]+r.mean2
		if(lim>lecho)
			lim=lecho
		if(!is.na(fin.E1[i])){
			fin.E1[i]<-(fin.E1[i])+
			which.min(r.zoom$lisse[i,fin.E1[i]:lim])-1
			lim<-fin.E1[i]+r.zoom2
			if(lim>lecho)
				lim=lecho
			fin.E1[i]<-(fin.E1[i]-r.zoom2)+
				which.min(sonardata[i,(fin.E1[i]-r.zoom2):(lim)])-1
		}else{}
	}
	tmp<-which(fin.E1>=lecho-25)
	if(length(tmp)!=0)
		Flags[tmp]<-0.5
	tmp<-which(Flags>1 & fin.E1*2>=lecho)
	if(length(tmp)!=0)
		Flags[tmp]<-1.5

#### Trouve le dbut de l'echo2

	for(i in which(Flags>=1.5)){
		tmp<-(which(r.mean$lisse[i,Pmn.sE1[i]:Pmx.sE2[i]]<=StartE2))
		if(length(tmp!=0)){
			debut.E2[i]<-Pmn.sE1[i]+max(tmp, na.rm=TRUE)-1
		}else{
			#debut.E2[i]<-Pmn.sE1[i]
			#	Flags[i]<-1
		}
		if(!is.na(debut.E2[i])){
			debut.E2[i]<-(debut.E2[i]-r.mean2)+
			which.min(r.zoom$lisse[i,(debut.E2[i]-r.mean2):(debut.E2[i])])-1
			debut.E2[i]<-(debut.E2[i]-r.zoom2)+which.min(
				sonardata[i,(debut.E2[i]-r.zoom2):(debut.E2[i]+r.zoom2)])-1
		}else{}
	}
	tmp<-which(Flags>1.5 & debut.E2>=lecho-25)
	if(length(tmp)!=0)
		Flags[tmp]<-1

#### Trouve la fin l'echo2

	for(i in which(Flags>=2)){
		tmp<-(which(r.mean$lisse[i,Pmx.sE2[i]:limE2[i]]<=EndE2))
		if(length(tmp!=0)){
			fin.E2[i]<-Pmx.sE2[i]+min(tmp, na.rm=TRUE)-1
		}else{
			#fin.E2[i]<-NA
			Flags[i]<-1.5
		}
		if(!is.na(fin.E2[i])){
			lim<-fin.E2[i]+r.mean2
			if(lim>lecho)
				lim<-lecho
			fin.E2[i]<-(fin.E2[i])+
			which.min(r.zoom$lisse[i,fin.E2[i]:lim])-1
			lim<-fin.E2[i]+r.zoom2
			if(lim>lecho)
				lim<-lecho
			fin.E2[i]<-(fin.E2[i]-r.zoom2)+
				which.min(sonardata[i,(fin.E2[i]-r.zoom2):lim])-1
		}else{}
	}
	
#### To trouble shoot erroneous detection behaviour...  no time to fix it
	
	tmp<-which(Flags>1 & is.na(debut.E2))
	if(length(tmp)!=0)
		Flags[tmp]<-1
	tmp<-which(fin.E2<=debut.E2)
	if(length(tmp)!=0)
		Flags[tmp]<-1
	tmp<-which(Pmx.sE2<=debut.E2)
	if(length(tmp)!=0)
		Flags[tmp]<-1
	tmp<-which(fin.E1<=debut.E1)
	if(length(tmp)!=0)
		Flags[tmp]<-0
	tmp<-which(Pmx.sE1<=debut.E1)
	if(length(tmp)!=0)
		Flags[tmp]<-0
	
					
	xx<-cbind(Vmx.sE1, Pmx.sE1, Vmn.sE1, Pmn.sE1,Vmx.sE2, Pmx.sE2, Vmn.sE2, 
		Pmn.sE2, debut.E1, fin.E1, debut.E2, fin.E2)
	colnames(xx)<-c("Vmx.sE1", "Pmx.sE1","Vmn.sE1", "Pmn.sE1", "Vmx.sE2", 
		"Pmx.sE2","Vmn.sE2", "Pmn.sE2", "debut.E1", "fin.E1", "debut.E2", 
		"fin.E2 ")
	return(list(xx=xx, Flags=Flags, StartE1=StartE1, EndE1=EndE1, 
		StartE2=StartE2, EndE2=EndE2, r.mean=r.mean$lisse, r.zoom=r.zoom$lisse, 
		r.mean=r.mean$lisse))
}

