"runningfilter" <- 
function(datum, g, method = c("max", "min", "mean", "median")) {

# DEFINITION

# Moving average of 'g' consecutive intensity values in a sonar return  
# It uses four methods: max, min, mean or median

# INPUT

# datum			The data on which to perform the transformation must be either as a vector or a matrix, must be real numbers.  
# g				The width of the moving window.  If median method is used , note that for any window not odd, -1 will be applied to the moving window. 
# method 		The method used on the moving window, max, mean or median		

	#Stop the function if:
	if(is.vector(datum)==TRUE){
		if(g>length(datum)) stop("'g' is larger than 'datum'.\n")
	}else if(is.matrix(datum)==TRUE){
		if(g>ncol(datum)) stop("'g' is larger than 'datum' rows length.\n")
	}else{
		stop(paste("Error in 'runningfilter.r':\n",
			"The 'datum' must either be a vector or a matrix.\n",
			sep=""))	
	}
	if (any(is.na(datum))){  
        stop(paste("Error in 'runningfilter.r':\n",
        	"na entries are found in table.\n"))
    }
   	if (any(is.infinite(datum))){  
        stop(paste("Error in 'runningfilter.r':\n",
        	"Inf entries are found in table.\n"))  
    }
	#Store the matrix or vector label
	row.n<-rownames(datum)
	col.n<-colnames(datum)
	method=tolower(method)

	#Loading the C code
	#dyn.load("~/STATSR/_Packages/C/runningfilter.so")
		
	if(is.vector(datum)){
		nr=1
		nc=length(datum)
	}else{
		nc=ncol(datum)
		nr=nrow(datum)	
	}
	datum<- switch(match.arg(method), 
		max = {
			matrix(.C("Rollmax",as.double(t(datum)), as.integer(g), 
			as.integer(nr), as.integer(nc), max = as.double(datum),
			PACKAGE="sonarX")$max, nrow=nr, ncol=nc, byrow=TRUE)
		},
		min = {
			matrix(.C("Rollmin",as.double(t(datum)), as.integer(g), 	
			as.integer(nr), as.integer(nc), min = as.double(datum),
			PACKAGE="sonarX")$min, nrow=nr, ncol=nc, byrow=TRUE)
		}, 
       	mean = {
			matrix(.C("Rollmean",as.double(t(datum)), as.integer(g), 	
			as.integer(nr), as.integer(nc), mean = as.double(datum),
			PACKAGE="sonarX")$mean, nrow=nr, ncol=nc, byrow=TRUE)
		},
        median = {
			matrix(.C("Rollmed",as.double(t(datum)), as.integer(g), 	
			as.integer(nr), as.integer(nc), median = as.double(datum),
			PACKAGE="sonarX")$median, nrow=nr, ncol=nc, byrow=TRUE)
		}
	)
	return(datum)
}