"variable" <-
function(normecho1, datum, lisse){

# DESCRIPTION

# We prepare the matrix of extracted variable for printing into an output file.
# Many variables are computed in the routine

# INPUT

#V.NewAlt	<- 		The computed altitude
#Pmx.sE1 	<- 		Point of maximum found in the smoothed E1
#Pmn.s 		<-		Point of minimum found between smoothed E1 and E2
#Pmx.sE2	<-		Point of maximum found in the smoothed E2
#Vmx.sE1	<-		Maximum value in the smoothed E1
#Vmn.s		<-		Minimum value found between smoothed E1 and E2
#Vmx.sE2	<-		Maximum value in the smoothed E2
#DRSx.E1	<-		Time distance between rise and set area centroids of E1
#DRSy.E1	<-		Intensity distance between rise and set area centroids of E1
#Area.R.E1	<-		Area below the curve of E1 rise section
#Area.S	.E1	<-		Area below the curve of E1 set section
#Area.T.E2	<-		Area below the curve of E2 rise section
#Area.RT.E1	<-		Proportion between E1 rise and E1 total area
#Area.RT.E2	<-		Proportion between E1 rise and E2 rise area
#Time.R.E1	<-		Time laps of E1 rise section
#Time.S.E1	<-		Time laps of E1 set section
#Time.T.E2	<-		Time laps of E2 rise section
#Time.RT.E1	<-		Proportion between E1 rise and E1 total time laps
#Time.RT.E2	<-		Proportion between E1 rise and E2 rise time laps
#Var.E1		<-		Variance (second statistical moment)
#Skew.E1	<-		Skewness (derived from third statistical moment)
#Histo1		<-		1st histogram class of E1 intensities, based on matrix max
#...............................................................................
#Histo7		<-		7th histogram class of E1 intensities, based on matrix max
	
	
	DRSx.E1<-datum[,mn("C.S.x.E1", mat=datum)]-
		datum[,mn("C.R.x.E1", mat=datum)]
	DRSy.E1<-abs(datum[,mn("C.S.y.E1", mat=datum)]-
		datum[,mn("C.R.y.E1", mat=datum)])
	Area.RS.E1<-datum[,mn("Area.R.E1", mat=datum)]/
		datum[,mn("Area.S.E1", mat=datum)]
	Area.RS.E2<-datum[,mn("Area.R.E2", mat=datum)]/
		datum[,mn("Area.S.E2", mat=datum)]
	Area.R.E1E2<-datum[,mn("Area.R.E1", mat=datum)]/
		datum[,mn("Area.R.E2", mat=datum)]
	Time.RS.E1<-datum[,mn("Time.R.E1", mat=datum)]/
		datum[,mn("Time.S.E1", mat=datum)]
	Time.RS.E2<-datum[,mn("Time.R.E2", mat=datum)]/
		datum[,mn("Time.S.E2", mat=datum)]
	Time.R.E1E2<-datum[,mn("Time.R.E1", mat=datum)]/
		datum[,mn("Time.R.E2", mat=datum)]
	TMP<-cbind(datum[,mn("TimeSPM", mat=datum)], 
		datum[,mn("V.NewAlt", mat=datum)],datum[,mn("Flags", mat=datum)])
	colnames(TMP)<-c("TimeSPM", "Altitude", "Flags")
	VE<-cbind(TMP, datum[,mn("V.NewAlt", mat=datum)], 
					datum[,mn("Vmx.sE1", mat=datum)], 
					datum[,mn("Vmn.sE1", mat=datum)], 
					datum[,mn("Vmx.sE2", mat=datum)],  
					DRSx.E1, DRSy.E1, Area.RS.E1, Area.RS.E2, Area.R.E1E2, 
					datum[,mn("Skew.E1", mat=datum)],
					datum[,mn("Histo", mat=datum)])
	colnames(VE)<-c(	"TimeSPM", "Altitude", "Flags", "V.NewAlt", "Vmx.sE1",
		"Vmn.sE1", "Vmx.sE2", "DRSx.E1",  "DRSy.E1", "Area.RS.E1", "Area.RS.E2",
		"Area.R.E1E2", "Skew.E1", "Histo1", "Histo2", "Histo3", "Histo4", 
		"Histo5", "Histo6", "Histo7")
	normecho1<-meanIntTransf(normecho1)
	VI<-cbind(TMP, normecho1)
	return(list(VE=VE, VI=VI))
}

