variation.filter<-function(mat, ID=NULL, scaling=TRUE, binary=FALSE, 
	min.numb=10){


# DESCRIPTION

# The aim here is to remove variables that has very limited degree of variation

# INPUT

# mat 				This is the variable matrix to filter
# ID	 			This the identification matrix
#					filtered
# binary			TRUE or FALSE
# min.number		In order to keep a variable how much different values it 
#					must have.  If binary == TRUE, this option will not be used
	if(is.data.frame(mat))
		mat<-as.matrix(mat)
	if(is.null(ID))
		ID=matrix(0,nrow(mat),4)
	if(binary==TRUE){
		mat<-sd.min10(mat, ID=ID, scaling=scaling, 
			binary=binary, min.numb=min.numb)
	}else{
		if(is.null(ID[,4])){
			stop("ID grouping values are missing")
		}else{}
		mat<-sd.min10(mat, ID=ID, scaling=scaling)	
	}
	return(mat)
}
sd.min10<-function(mat, ID=NULL, scaling=FALSE, binary=TRUE, min.numb=10){
	for(n in levels(as.factor(ID[,4]))){
		nc<-ncol(mat)
		j<-NULL
		#### Reads the grouping column
		kk<-which(ID[,4]==n)	
		if(length(kk)==1){
			cat("We remove the only sample found in group",n,"\n")
			mat<-mat[-kk,]
			ID<-ID[-kk,]
		}else if (length(kk)==0){
		}else{
			tmp<-apply(mat[kk,1:nc], 2, sd, na.rm=TRUE)
			j<-which(tmp==0)
			if(length(j)!=0){
				mat<-mat[,-j]
			}else{}
		}
	}
	if(binary!=TRUE){
		#### Remove the variables that has less than 10 different values 
		del<-which(apply(mat, 2, function(x) length(unique(x)))<min.number)
		#### Nothing is removed
		if(length(del)==0){ 
			del<--(1:ncol(mat)) 
		}else{}
		mat<-mat[,-(del)]
	}else{}
	#### We are scaling the data
	if(scaling==TRUE){
		mat<-scale(mat)
	}
	return(list(mat=mat, ID=ID))
}