\name{analyse}
\alias{analyse}

\alias{cleanup.NA.Inf}

\alias{correl.filter.VE}
\alias{correl.filter.VI}
\alias{variable.selection}
\alias{data.screening}

\alias{ellipse} %Goes in most graphics and would require a description

\alias{multi.factor} %Graphics
\alias{probFrda}	%Graphics

\alias{variation.filter}
	\alias{sd.min10}

\alias{specifictimes}
\alias{splitByAlt}
\alias{transf}

\alias{vif}

\title{ Analysis of the matrices of sonar variables created by extract.R.}
\description{
  This function analyses the two matrices generated by the \code{\link{extract}} function. It can compute either a canonical redundancy analysis (RDA) or a linear discriminant analysis (LDA). Cross-validation can be performed, different altitude sections can be analysed separatly. If no classificaiton vector (class.vec) is provided, several partitions will be found by K-means; the partition that corresponds to the maximum value of the Calinsky-Harabasz criterion will be selected.
}
\usage{
analyse(
	extract.data=NA, VIS=NA, alt.sect=NULL, 
	flag=0, use= "VT", keep=NA, method="RDA", class.vec=NULL,
	validation.perc=0.30, nperm=999, criterion="calinski", 
	select.grpmt=TRUE, min.g=2, max.g=25, grpmts.plot=TRUE, 
	dateformat="\%d-\%b-\%Y", timesep=":", print.res=TRUE
	)
}
 
\arguments{
  \item{ extract.data }{ This can be either the loaded output list created by the \code{\link{extract}} function, or the path to the "extract.RData" file which contains the list. It can also be left to \code{NULL}; in that case, the user will be asked to choose a file.
  }
  \item{ VIS }{ This can be either a loaded matrix or a path to a .TXT table. The information found in this table contains the visual analysis of the footprint areas. Continous monitoring was performed and the information seen was described for each second of the sonar surveys; see \code{\link{VIS.analysis}}. Note: no VIS file will be used with the \code{"LDA"} method (see \code{\link{ldaTest}}), but it is necessairy when using the \code{"RDA"} method (see \code{\link{rdaTest}}). If a VIS file is required while this parameter is equal to \code{NA}, a selection browser will pop up. 
  }
  \item{ alt.sect }{ This parameter is used when the echo variables from different altitude of acquisition are to be analysed separately. A matrix defining the selected altitude ranges in meters (n x 2) must be provided. Column 1 contains the beginning (inclusive) while column 2 contains the end (exclusive) of each altitude section. Each line corresponds to a separate altitude section on which the analysis will be performed. If \code{NULL}, the whole altitude range found in the data set will be used in the analysis. }
  \item{flag}{ This parameter indicates which flag state should be used in the analysis. 
    \item{\code{2}}{	Use the first and second echo sections.}
    
    
    \item{\code{1.5}}{	Use both the first echo and second echo rise sections.}
    
    
    \item{\code{1}}{	Use only the first echo sections.}
  }
  \item{ use }{ Defines which variable set will be used in the analysis.
    \item{\code{"VT"}}{	The analysis is run on the combined set of intensity and extracted variables (combines the VI and VE matrices).}
    
    
    \item{\code{"VE"}}{	The analysis is run on the extracted variables (VE) only.}
    
    
    \item{\code{"VI"}}{	The analysis is run on the intensity variables (VI) only.}
  }
  \item{ keep }{ This is either a loaded matrix or a path to a .TXT table. This matrix gives the times sections that are to be use in the analysis. The matrix is of dimension (n x 4). In columns 1 and 2, it provides the date and time of each section starting point; in the columns 3 and 4 are found the date and time of the end of these sections. Make sure that the date format is the same as specified in \code{dateformat}. 
  }
  \item{ method }{ This is either linear discriminant analysis (\code{"LDA"}, see \code{\link{ldaTest}}) or canonical redundancy analysis (\code{"RDA"}, see \code{\link{rdaTest}}). The \code{"RDA"} method requires a matrix of response variables and a set of site visual descriptors describing continuously the studied area. Since the k.means parameter is set to \code{TRUE} by default, a partition will be produced and shown in the plot using either ellipses or stars. The \code{"LDA"} method requires a grouping vector. If no vector is provided, a  partition is produced by K-means.
  }
  \item{ class.vec }{ A vector of classes can be provided for every sonar return. If none is provided, one will be created by K-means analysis of the sonar data. If more than one altitude section is given, class.vec will be estimated for each submatrix. This option works only for the \code{"LDA"} method. 
  }
  \item{ validation.perc }{ If the \code{"LDA"} method is used, a model is produced and written to the output object. If the value of this parameter is \code{1}, 100 \% of the data will be used to construct and validate the model. If \code{0.7} is used, 70 \% of the data will be used to construct the model and the other random 30 \% will be used to validate the model. If 0 \% is used, a pop-up browser will appear and will ask the user to load an existing model and run the data on it (option not implemented yet). 
  }
  \item{ nperm }{ The number of permutations used in the tests of significance. 
  }
  \item{ criterion }{ 15 different criteria can be used to decided about the best partition of the data. The default is \code{"calinski"}. See the help file of the \code{\link{cclust}} package. 
  }
  \item{ select.grpmt }{ Allows the user to select its own partition if \code{TRUE} (default value).
  }
  \item{ min.g }{ The minimum number of groups in the K-means partition cascade; the default value is \code{2}. 
  }
  \item{ max.g }{ The maximum number of groups in the K-means partition cascade; the default value is \code{25}. 
  }
  \item{ grpmts.plot }{ Shows a plot of the best partition obtained by K-means, see \code{criterion}. 
  }
  \item{ dateformat }{ This is the date format; see \code{\link{format.Date}} and \code{\link{strptime}} for details. 
  }
  \item{ timesep }{ This defines the time format separator. The default value is ":".
  }
  \item{ print.res }{ Either TRUE or FALSE. When TRUE, the results are printed in the R window.
  }
}
\details{
  This is a beta version.
}
\value{
  A list is returned. For each matrix that was analysed, the results of either \code{\link{ldaTest}} or \code{\link{rdaTest}} are stored in that list. Consequently to reach them, type (for instance) s\$results[[1]].
}
\references{ Legendre, P. and L. Legendre. 1998. Numerical Ecology. Second English edition. Elsevier, Amsterdam.

Legendre, P., K. E. Ellingsen, E. Bjornbom and P. Casgrain. 2002. Acoustic seabed classification: improved statistical method. Canadian Journal of Fisheries and Aquatic Sciences 59: 1085-1089.

MacQueen, J. 1967. Some methods for classification and analysis of multivariate observations. 281-297 in: Le Cam L.M. and J. Neyman [eds.] Proceedings of the Fifth Berkeley Symposium on Mathematical Statistics and Probability. Volume 1. University of California Press, Berkeley.
}
\author{ Sebastien Durand <Sebastien.Durand@umontreal.ca> }

\seealso{ 
	\code{\link{import.imatxt}}, 
	\code{\link{extract}}, 
	\code{\link{rdaTest}}, 
	\code{\link{ldaTest}}
}
\examples{ 
data(ALTextract)

#----------------------------------#
# ANALYSIS OF A VERTICAL TRANSECTS #
#----------------------------------#

# Constructing a partition vector based on the acquisition times

times<-time2spm(date=extract.data$VE[,1], time=extract.data$VE[,2], 
	dateformat="\%Y-\%m-\%d") 
lava<- time2spm(date=c("19-AUG-2002","19-AUG-2002"), 
 	time=c("19:55:02.64","20:23:34.55")) 
peri<- time2spm(date=c("19-AUG-2002","19-AUG-2002"), 
	time=c("20:23:34.56","20:52:31.90"))
tube<- time2spm(date=c("19-AUG-2002","19-AUG-2002"), 
	time=c("20:52:31.91","21:32:00.67"))
limp<- time2spm(date=c("19-AUG-2002","19-AUG-2002"), 
	time=c("21:32:00.68","21:54:44.80"))
clam<- time2spm(date=c("19-AUG-2002","19-AUG-2002"), 
	time=c("21:54:44.81","22:22:48.39"))
class.vec<-rep(0,length(times))
	for (i in 1:length(times)){
		if(times[i]>=lava[1] & times[i]<lava[2]) class.vec[i]<-1
		if (times[i]>=peri[1] & times[i]<peri[2]) class.vec[i]<-2
		if (times[i]>=tube[1] & times[i]<tube[2]) class.vec[i]<-3
		if (times[i]>=limp[1] & times[i]<limp[2]) class.vec[i]<-4
		if (times[i]>=clam[1] & times[i]<clam[2]) class.vec[i]<-5
	}
	v<-class.vec
	v[v==1]<-"Lava";
	v[v==2]<-"Peri";
	v[v==3]<-"Tube";
	v[v==4]<-"Limp";
	v[v==5]<-"Clam";
class.vec<- factor(v)	
# Linear discriminant analysis (LDA) is used for the analysis
s<-analyse(extract.data=extract.data, VIS=NA, 
	alt.sect=NULL, use= "VT", keep=NA, class.vec=class.vec, 
	validation.perc=0.30,
	nperm=9, criterion="Calinski", select.grpmt=TRUE, flag=2, 
	method="LDA", grpmts.plot=TRUE)


#--------------------------------------------#
# ANALYSIS OF A TYPICAL HORIZONTAL TRANSECTS #
#--------------------------------------------#
data(INTextract)
# Along with a visual transect
data(VIS.analysis)
# Redundancy analysis (RDA) is used for the analysis
s<-analyse(extract.data=extract.data, VIS=VIS.analysis, 
	alt.sect=NULL, use="VT", keep=NA, class.vec=NULL, 
	validation.perc=0.30, nperm=9, 
	criterion="Calinski", select.grpmt=FALSE, flag=2, 
	method="RDA", grpmts.plot=TRUE)
}
\keyword{manip}
