\name{extract}
\alias{extract}
\alias{airefraction}
\alias{altitude.filter}
\alias{area.centroid.time}
	\alias{tct}

\alias{TimeNormAdj}
%Functions used to locate the echoes
\alias{consecutive}
\alias{echostartend}
\alias{rechecho}
%Function used to correct the echoes, requires a better definition.
\alias{correction}

\alias{echoextract}
\alias{filtre}
\alias{findalt}
\alias{graph.depthnorm}
\alias{histo}
\alias{lissagepargroupe} %Would benifit from a description 
\alias{meanIntTransf}
\alias{meanecho}
\alias{mn}  %Would benifit from a description

\alias{mom}
\alias{moments}

\alias{norm.puissance} %Requires a good description
\alias{norm.temporal} %Requires a good description
\alias{rmnoise}
\alias{runningfilter}

\alias{spm2time}
\alias{time2spm}
\alias{timeCheck}
\alias{variable}

\title{ Extraction function that also filters and corrects the sonar data }
\description{
Prior to the extraction of the two datasets, \code{VE} and \code{VI},
the data in each sonar return are corrected, filtered, and depth-normalized by this function.
}
\usage{
extract( 
	import.datum=NA, save.data=FALSE, save.plot=FALSE, PathOut=NA, 
	Prefix=NA, show.echoes=FALSE, show.profiles=FALSE, avegroup=1, 
	avesec=FALSE, time.filter=NA, timelaps=13.333, maximumv=14000, 
	pulse=100, tooweak=1000, newspacing=10, reson=25, soundspeed=1500, 
	alt.trigger=0.8, depth.ref=1, nb=5, dateformat="\%d-\%b-\%Y", 
	timesep=":", perc.jump=0.001, thresh.high=0.05, thresh.low=0.005, 
	abs.rate.ori=0.2, logf.ori=40, start.gain.ori=6, abs.rate.cor=-0.2, 
	logf.cor=40, start.gain.cor=6, abs.rate.ref=-0.1, logf.ref=0, 
	start.gain.ref=6, expos=2, quiet=TRUE )
}

\arguments{
  \item{import.datum}{ The output list produced by the \code{\link{import.imatxt}} function. 
  }
  \item{save.data}{ Will the data produced by this function be save in a file, \code{TRUE} or \code{FALSE}. The default is \code{FALSE}, see \code{PathOut}. 
  }
  \item{save.plot}{ If save.plot is set to TRUE and show.profiles is also TRUE, a .PDF version of this plot will be created and the plot will not show in the graphics window. The default is \code{FALSE}; see \code{PathOut}.
  }
  \item{PathOut }{ The path to the folder where the output files will be created. If \code{Prefix} is set to TRUE, the output files will be stored in the "\_Results" folder and the basename given in the path will serve as the file prefix. If no path is provided, the "\_Results" folder will be created in the folder containing the first file read by the \code{\link{import.imatxt}} function.
  }
  \item{Prefix }{ A logical value. If \code{Prefix} is set to TRUE, the basename given in \code{PathOut} will added at the beginning of the name of each output file. If set to \code{FALSE} no prefix will be added.  
 }
  \item{show.echoes}{ Produces a graph showing where the program splits and finds the first and second echo starting and ending points of each sonar return. The default is FALSE. 
  }
  \item{show.profiles}{ Produce a graph showing the depth normalisation effect on the data intensities. The default is TRUE. Because of the large number of points drawn, that plot may take long to produce (the X11 device was found to be much faster at drawing this plot). This plot is very useful to try values and and find the proper absorption rate that should be used in order to properly remove the effect of depth embedded in the recorded signals.
  }
  \item{avegroup}{ The number of consecutive sonar returns to average out. The default is \code{1}: no averaging is done. If set to \code{3}, each set of three consecutive echoes is averaged. 
  }
  \item{avesec}{ When set to \code{TRUE}, all sonar returns found within a one second interval are averaged. The default is \code{FALSE}. This setting is used specially when a comparison will be made with a visual survey acquired with one second intervals.
  }
  \item{time.filter}{ The complete path of a file contaning erroneous time ranges, describing sections that have to be removed from the dataset. The default is NA. This .TXT file contains 4 columns. In the first two columns, we have the date and starting time, while in the third and fourth columns are the ending date and time of the erroneous sections.
  }
  \item{timelaps}{ The timelapse between recorded echo intensities. The default is 13.333 microseconds. 
  }
  \item{maximumv}{ The maximum intensity value that can be recorded by the sonar software. The default is \code{14000}. All intensity values will be converted to the 0 - maximumv intensity scale. 
  } 
  \item{pulse}{ This is the sonar pulse length in microseconds. The default is \code{100} microseconds.
  }
  \item{tooweak}{ While searching for the correct altitude of acquisition value for each sonar return, \code{tooweak} defines the lower searching limit. The default is \code{1000} for a 14000 intensity maximum. Echoes with intensity peaks lower than \code{tooweak} will be discarded.
  }
  \item{newspacing}{ Due to the depth normalisation procedure, time compression or extension is necessary, leading to a necessary intensity resampling. \code{newspacing} is the new timelapse that will be used to resample the sonar return intensities. The default is \code{10} microseconds. 
  }
  \item{reson}{ The number of intensity values required to insure that the resonance effect has dissipated from the sonar returns. The default is 25; this setting would exclude from the analysis the first 25 intensity values found in every sonar returns. 
  }
  \item{soundspeed}{ The speed of sound in water. The default is 1500 metres per second. Set your own value using http://freespace.virgin.net/sd.richards/speed.html.
  }
  \item{alt.trigger}{ In each sonar return, once the maximum has been found, a search is initiated to find the first point reaching 80\% of that maximum. The altitude of the sonar head will be estimated from a point around this value. The default for alt.trigger is 0.8. 
  }
  \item{depth.ref}{ Since the sonar returns are depth-normalised, \code{depth.ref} sets the reference depth. The default is 1 metre. 
  }
  \item{nb}{ This is a search criterion. The program will look for \code{nb} consecutively increasing values to determine the echo starting point, and \code{nb} consecutively decreasing value to determine the echo ending point. If no such sequences are found with \code{nb}, \code{nb}-1 will be used, and so forth until a echo starting and ending locations are identified.
  }
  \item{ dateformat }{ This is the date format; see \code{\link{format.Date}} and \code{\link{strptime}} for details. 
  }
  \item{timesep}{ This defines the time format separator. Default is \code{:}. 
  }
  \item{perc.jump}{ The percentage of the echo maximum that must be jumped to be considered a valid intensity increase or decrease. The default is 0.001. See \code{nb}. 
  }
  \item{thresh.high}{ To find an echo start or end position, one of the consecutive \code{nb} values must be higher than the thresh.high percentage. The default is 0.05. 
  }
  \item{thresh.low}{ After the echo starting or ending points have been located,  the nearest value found below the \code{thresh.low} percentage of the echo maximum is used as a reference for echo start and end detection. The default value is 0.005 \%. 
  }
  \item{abs.rate.ori}{ Absorption rate used while surveying. Default is \code{0.2}.
  }
  \item{logf.ori}{ LogF value used while surveying. Default is \code{40}.
  }
  \item{start.gain.ori}{ Start gain value used while surveying. Default is \code{6}.
  }
  \item{abs.rate.cor}{ Corrected absorption rate. Default is \code{-0.2}.
  }
  \item{logf.cor}{ Corrected LogF value. Default is \code{40}.
  }
  \item{start.gain.cor}{ Corrected start gain value. Default is \code{6}.
  }
  \item{abs.rate.ref}{ The absorption reference rate. Default is \code{-0.1}.
  }
  \item{logf.ref}{ LogF reference value. Default is \code{0}.
  }
  \item{start.gain.ref}{ Start gain reference value . Default is \code{6}.
  }
  \item{expos}{ Exponent value used in the power correction. Default is \code{2}. See Les Hamilton work for more details.
  }
  \item{quiet}{ If set to \code{False}, more details will be given during computation. Default is \code{TRUE}.
  }
}
\value{
	A list called \code{extract.data} is returned and saved in PathOut.
  \item{ "VE" }{ Data matrix describing all echoes using the following 21 extracted variables:
    \item{ Date }{ Sonar return date of acquisition (YYYY-mm-dd).
    }
    \item{ Time }{ Sonar return time of acquisition.
    }
    \item{ Altitude }{ Computed altitude (serves as ID).
    }
    \item{ Flag }{ How many echoes are found in each sonar return.
    }
    \item{ V.NewAlt }{ Computed altitude (serves as variable).
    }
    \item{ Vmx.sE1 }{ Maximum value in the smoothed E1.
    }
    \item{ Vmn.sE1 }{ Minimum value found between smoothed E1 and E2.
    }
    \item{ Vmx.sE2 }{ Maximum value in the smoothed E2.
    }
    \item{ DRSx.E1 }{ Time distance between rise and set area centroids of E1.
    }
    \item{ DRSy.E1 }{ Intensity distance between rise and set area centroids of E1.
    }
    \item{ Area.RS.E1 }{ Proportion between E1 rise and E1 set area.
    }
    \item{ Area.RS.E2 }{ Proportion between E2 rise and E2 set area.
    }
    \item{ Area.R.E1E2 }{ Proportion between E1 rise and E2 rise area.
    }
    \item{ Skew.E1 }{ Skewness value derived from the third statistical moment.
    }
    \item{ Histo1 }{ 1st histogram class of E1 intensities, based on matrix max.
    }
    \item{ Histo... }{ ...
    }
    \item{ Histo7 }{ 7th histogram class of E1 intensities, based on matrix max.
    }
 }
 \item{ "VI" }{ A data matrix describing all echoes using intensity variables:
   \item{ Date }{ Sonar return date of acquisition (YYYY-mm-dd).
   }
   \item{ Time }{ Sonar return time of acquisition.
   }
   \item{ Altitude  }{ Computed altitude.
   }
   \item{ Flag }{ How many echoes are found in each sonar return.
   }
   \item{ Int1-5 }{ Averaged value of the first five intensities.
   }
   \item{ Int6-10 }{ Averaged value of the 6th to 10th intensities.
   }
   \item{ Int...  }{ Continue till all intensity values have been averaged.
   }
 }
 \item{ "call" }{ The call used to run the function.
 }
}
\references{ Clarke, P. A. and L. J. Hamilton. 1999. The ABCS Program for the analysis of echo sounder returns for acoustic bottom classification. Defence Science & Technology Organisation. 

Hamilton, L. J. 2001. Acoustic seabed classification systems. Defense Science & Technology Organisation.
}
\author{ Sebastien Durand <Sebastien.Durand@UMontreal.ca }
\note{ This is a beta version; the smoothing algorithm used will be improved in order to increase calculation speed. The functions used to locate the echo starting and ending points will also be modified. }

\seealso{ 
	\code{\link{import.imatxt}},
	\code{\link{analyse}}
}
\examples{

#Loading import.imatxt function output

#Example 1
data(vertical.transects) 
#These are sonar data acquired through vertical transects where each transect were acquired over only one habitat; five different habitats were sampled.
s<-extract( import.datum=vertical.transects, 
	PathOut="~/ALT.TXT", Prefix=TRUE, save.plot=FALSE,
	avegroup=1, avesec=FALSE, time.filter=NA, timelaps=13.333, 
	maximumv=14000, pulse=100, tooweak=1000, newspacing=10,
	reson=25, show.echoes=FALSE, show.profiles=TRUE, soundspeed=1500,
	alt.trigger=0.8, depth.ref=1, nb=5,dateformat="\%d-\%b-\%Y", timesep=":")

#Example 2
data(horizontal.transects)
#These are sonar data acquired through horizontal transects representing the whole habitat gradient.
s<-extract( import.datum=horizontal.transects, 
	PathOut="~/INT.TXT", Prefix=TRUE)
}
\keyword{manip}
\keyword{datagen}
