\name{graph.ldaTest}
\alias{graph.ldaTest}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Display ldaTest results }
\description{
	This is a highly flexible drawing device for discriminant analysis results.
}
\usage{
graph.ldaTest(
	ldaTest, xax=1, yax=2, plot.what="p.assign", binary=NULL, 	
	centroids=TRUE, ell=TRUE,  sites=TRUE, stars=TRUE, 
	alpha=0.95, filter.env=NULL, saveplot=FALSE, path=NULL, width=6, height=6, 
	xlim=NULL, ylim=NULL, lwd=1, len=0.1, 
	lty.env=1, lty.ell=1, lty.axis=2, lty.stars=1, 
	col.env="blue", col.groups=NULL, col.ell="black", col.ctd="black",
	pos.env=4, pos.bin=4, pos.site= NULL, pos.ctd=4,
	cex.env=1, cex.site=1, cex.ctd=1, cex.axis=1,
	pch.bin=21, pch.site=21, pch.ctd=23, 
	ell.axis=FALSE, mul.env=0.9
	)
}
%- See also 'usage' for other objects documented here.
\arguments{
  \item{ldaTest}{ The \code{\link{ldaTest}} output.
  }
  \item{xax}{ The matrix column to be used as the abscissa of the lda graph. This value can be negative; if so, the plot axis will be reversed.
  }
  \item{yax}{ The matrix column to be used as the ordinate of the lda graph. This value can be negative; if so, the plot axis will be reversed.
  }
  \item{plot.what}{ Can be set to either \code{"model"},\code{"observe"}, or \code{"assign"}. If \code{"model"} is selected, the data used to construct the model as well as the original (observed) groups are shown. If \code{"observe"} is used, the data used for validation are plotted along with the observed groups. Finally and the default, the data used in model validation are plotted along with the groups assigned to them by the model.
  }
  \item{binary}{ A vector specifying which of the environmental variables are binary. The data points possessing the characteristics in question will be averaged and represented by a symbol instead of an arrow, as in Canoco.
  }
  \item{centroids}{ If set to TRUE, group centroids are drawn.
  }
  \item{ell}{ Draw confidence ellipses around groups of points defined by a vector defining the group assignments of the objects; see \code{alpha} below.
  }
  \item{sites}{ Shows by default the sites on the plot; "FALSE" will not display the sites.
  }
  \item{stars}{ Shows by default stars on the plot; stars are lines linking each site to its respective group centroid. "FALSE" will not display them.
  }
  \item{alpha}{The confidence region of the ellipses (e.g.: 0.90, 0.80, etc.) Default value: 0.95.
  }
  \item{filter.env}{A percentage value which filters out environmental variables associated to very short vectors. Based on the total length of all environmental variables, only those whose lengths are greater than the specified percentage will be displayed. The default is NULL: no filtering.
  } 
  \item{saveplot}{ The plot can be saved to a .pdf file. If set to \code{FALSE}, the plot will only be plotted in a window. If set to \code{TRUE}, no graph will be plotted on the screen, but a pdf file will created.
  }
  \item{path}{ Complete path to the file in which the plot will be saved; example: "~/Desktop/toto.pdf".
  }
  \item{width}{Plot width in inches.
  }
  \item{height}{Plot height in inches.
  }
  \item{xlim}{Vectors describing the x axis minimum and maximum of the plotted region.
  }
  \item{ylim}{Vectors describing the y axis minimum and maximum of the plotted region.
  }
  \item{lwd}{ Line width for the axes, arrows, and ellipses.
  }
  \item{len}{ Length of the arrow heads.
  }
  \item{lty.env}{ The environmental variables arrow drawing type.
  }
  \item{lty.ell}{ The drawing type for ellipses; see \code{lty} in the help documentation file of \code{\link{par}}.
  }
  \item{lty.axis}{ The drawing type of axes, dotted lines, etc. See \code{\link{par}}.
  }
  \item{lty.stars}{ The line type for stars. See \code{\link{par}}.
  }
  \item{col.env}{ The environmental variables arrow and text color.
  }
  \item{col.groups}{ By default, each group is assigned a different colour, so that sites and group centroids have an identifiable colour, which is a function of their group membership.
  }
  \item{col.ell}{ Colour of the ellipses.
  }
  \item{col.ctd}{ Colour of the centroids.
  }
  \item{pos.env}{ Position offset of the environmental variable names: 1=bottom, 2=left, 3=top, 4=right.
  }
  \item{pos.bin}{ Position offset of the binary environmental variables names: 1=bottom, 2=left, 3=top, 4=right.
  }
  \item{pos.site}{ Position offset of the site names: 1=bottom, 2=left, 3=top, 4=right.
  }
  \item{pos.ctd}{ Position offset of the group centroid names: 1=bottom, 2=left, 3=top, 4=right.
  }
  \item{cex.env}{ Font size for environmental variable labels.
  }
  \item{cex.site}{ Font size for sites labels.
  }
  \item{cex.ctd}{ Font size for centroid labels.
  }
  \item{cex.axis}{ Font size for axis names.
  }
  \item{pch.bin}{ Symbol used to represent binary variables. See \code{pch} definition in the \code{\link{points}} function.
  }
  \item{pch.site}{ Symbol used to represent sites. See \code{pch} definition in the \code{\link{points}} function.
  }
  \item{pch.ctd}{ Symbol used to represent centroids. See \code{pch} definition in the \code{\link{points}} function.
  }
  \item{ell.axis}{If TRUE, draw the major and minor axes of the ellipses.
  }
  \item{mul.env}{ The environmental variable arrows are initially expanded or compressed to fit within the plot borders and be displayed with maximum spread. \code{mul.env} is a multiplier used to modify the arrow proportions. By default, 0.90 is used to give some room for the arrow labels.
  }
}
\value{
  A plot is returned.
}
\author{ Sebastien Durand <Sebastien.Durand@UMontreal.ca> }

\seealso{ \code{\link{ldaTest}}}
\examples{

 data(lda.analyse)
 
# Default
 graph.ldaTest(s$results[[1]])

# Without the ellipses and sites
 graph.ldaTest(s$results[[1]], ell=FALSE, sites=FALSE, cex.ctd=2)

# Without in gray and without the stars
 graph.ldaTest(s$results[[1]], pch.site=10, col.groups=gray(0:3/3), stars=FALSE)

# With binary variables the ten first, and some visual filtering of weak 
# environmental variables

graph.ldaTest(s$results[[1]], col.groups=gray(0:3/3), stars=FALSE, 
	ell.axis=TRUE, col.ctd="red", binary=c(1:10), filter.env=0.04,cex.ctd=1.5)

# In a zoomed window
graph.ldaTest(s$results[[1]],sites=FALSE,col.ctd="red", 
	xlim=c(-2,2),ylim=c(-2,2), pos.env=3)

# Having filtered the environmental variables that does not show 
# much influence on the displayed axis
graph.ldaTest(s$results[[1]], col.groups=gray(0:3/3), stars=FALSE, 
	sites=FALSE,ell.axis=FALSE,col.ctd="red",filter.env=0.05, pos.bin=4, 
	pos.env=2, lty.axis=0)
}
\keyword{graphs}
\keyword{multivariate}
