\name{graph.rdaTest}
\alias{graph.rdaTest}
\title{ Display the rdaTest output }
\description{
	This is highly flexible drawing device
}
\usage{
graph.rdaTest(
	rdaTest, xax=1, yax=2, scaling=1, plot.type="notchosen", 	
	binary=NULL, groups=NULL, 
	centroids=TRUE, ell=TRUE, sites=TRUE, stars=FALSE, 
	label.env=TRUE, label.spc=TRUE, label.site=TRUE,
	alpha=0.95, saveplot=FALSE, path=NULL, width=6, height=6, 
	xlim=NULL, ylim=NULL,lwd=1, len=0.1,
	lty.env=1, lty.spc=1, lty.ell=1, lty.stars=1, lty.axis=2, 
	col.env="blue",col.spc="red", col.groups=NULL, col.ell="black", 	
	col.ctd="black",
	pos.env=NULL, pos.bin=4, pos.site=NULL, pos.ctd=4,
	cex.env=1, cex.spc=1, cex.site=1, cex.ctd=1, cex.axis=1,
	pch.bin=21, pch.site=21, pch.ctd=23, 
	ell.axis=FALSE, mul.spc=0.90, mul.env=0.90, mul.text=0.10,
	mai.perc=NULL)

}
%- See also 'usage' for other objects documented here.
\arguments{
  \item{rdaTest}{ The \code{\link{rdaTest}} output. 
  }
  \item{xax}{ The matrix columns to be used as the abscissa in the rda graph. These value can be negative; if so, the plot axes will be reversed. 
  }
  \item{yax}{ The matrix columns to be used as the ordinate in the rda graph. These value can be negative; if so, the plot axes will be reversed. 
  }
  \item{scaling}{ Allows the user to choose between the two scaling types, 1 or 2.
  }
  \item{plot.type}{ Either \code{"F"} = site scores, or \code{"Z"} = fitted site scores.
  }
  \item{binary}{ A vector specifying which of the environmental variables are binary. The data points possessing the characteristics in question will be averaged and represented by a symbol instead of an arrow, as in Canoco.
  }
  \item{groups}{ A vector describing the group assignment of all objects. 
  }
  \item{centroids}{A logical value (TRUE or FALSE) defining if centroids are to be drawn.
  }
  \item{ell}{A logical value (TRUE or FALSE) defining if confidence ellipses around groups of points are to be drawn. Group membership is described in \code{"groups"}. See examples below.
  }
  \item{sites}{A logical value (TRUE or FALSE) defining if the sites are to be drawn on the plot.
  }
  \item{stars}{A logical value (TRUE or FALSE) defining if stars (lines linking each site to its respective group centroid) are to be drawn on the plot.
  }
  
  \item{label.env}{ A logical value (TRUE or FALSE) defining if the environmental variable names are to be printed  on the plot.
  }
  \item{label.spc}{ A logical value (TRUE or FALSE) defining if the species names are to be printed on the plot.
  }
  \item{label.site}{ A logical value (TRUE or FALSE) defining if the site names are to be printed on the plot.
  }
  \item{alpha}{ The confidence region of the ellipses (e.g.: 0.90, 0.80, etc.) Default value: 0.95.
  }
  \item{saveplot}{ The plot can be saved to a .pdf file. If set to \code{FALSE}, the plot will only be plotted in a window. If set to \code{TRUE}, no graph will be plotted on the screen, but a pdf file will created.
  }
  \item{path}{ Complete path to the file in which the plot will be saved; example: "~/Desktop/toto.pdf".
  }
  \item{width}{ Plot width in inches. 
  }
  \item{height}{ Plot height in inches. 
  }
  \item{xlim}{ Vectors describing the x axes minimum and maximum of the plotted region.
  }
  \item{ylim}{ Vectors describing the y axes minimum and maximum of the plotted region.
  }
  \item{lwd}{ Line width for the axes, arrows, and ellipses.
  }
  \item{len}{ Length of the arrow heads. 
  }
  \item{lty.env}{ The environmental variables arrow drawing type.
  }
  \item{lty.spc}{ The species variables arrow drawing type.
  }
  \item{lty.ell}{ The drawing type for ellipses; see \code{lty} in the help documentation file of \code{\link{par}}.
  }
  \item{lty.stars}{ The line type for stars. See \code{\link{par}}.
  }
  \item{lty.axis}{ The drawing type of axes, dotted lines, etc. See \code{\link{par}}.
  }    
  \item{col.env}{ The environmental variables arrow and text colour. 
  }
  \item{col.spc}{ The species variables arrow and text colour. 
  }
  \item{col.groups}{ By default, each group is assigned a different colour, so that sites and group centroids have an identifiable colour, which is a function of their group membership.
  }
  \item{col.ell}{ Colour of the ellipses. 
  }
  \item{col.ctd}{ Colour of the centroids. 
  }
  \item{pos.env}{ Position offset of the environmental variable names: 1=bottom, 2=left, 3=top, 4=right. 
  }
  \item{pos.bin}{ Position offset of the binary environmental variables names: 1=bottom, 2=left, 3=top, 4=right. 
  }
  \item{pos.site}{ Position offset of the site names: 1=bottom, 2=left, 3=top, 4=right. 
  }
  \item{pos.ctd}{ Position offset of the group centroid names: 1=bottom, 2=left, 3=top, 4=right.
  }
  \item{cex.env}{ Font size for environmental variable labels.
  }
  \item{cex.spc}{ Font size for species names.
  }
  \item{cex.site}{ Font size for sites labels.
  }
  \item{cex.ctd}{ Font size for centroids labels. 
  }
  \item{cex.axis}{ Font size for axis names. 
  }
  \item{pch.bin}{ Symbol used to represent binary variables. See \code{pch} definition in the \code{\link{points}} function. 
  }
  \item{pch.site}{ Symbol used to represent sites. See \code{pch} definition in the \code{\link{points}} function. 
  }
  \item{pch.ctd}{ Symbol used to represent centroids. See \code{pch} definition in the \code{\link{points}} function. 
  }
  \item{ell.axis}{ If TRUE, draw the major and minor axes of the ellipses.
  }
  \item{mul.spc}{ The species variable arrows are initially expanded or compressed to fit within the plot borders and be displayed with maximum spread. \code{mul.spc} is a multiplier used to modify the arrow proportions. By default, 0.90 is used to give some room for the arrow labels. 
  }
  \item{mul.env}{ The same as \code{mul.spc} but for the environmental variable. 
  }
  \item{mul.text}{ Text position at the end of each arrow, plus a percentage of the arrow length; the default value is 10\%.
  }
  \item{mai.perc}{ Allows to increase or decrease the margin size, using a percentage of the total width and height of the graph. That value is between 0 and 1. 
  }  
}
\value{
  A plot is returned.
}
\author{ Sebastien Durand <Sebastien.Durand@UMontreal.ca> }

\seealso{ \code{\link{rdaTest}}}
\examples{
#see \code{\link{rdaTest}} 
data(rda.analyse)
graph.rdaTest(s$results[[1]], plot.type = "Z")

#Find groups 
toto<-cascadeKM(s$results[[1]][[6]],2,5,iter=9,criterion="calinski")
toto2<-plotKM(toto)
#in this case we take the 5 group solution 
graph.rdaTest(s$results[[1]], plot.type = "Z",groups=toto[[1]][,4],label.site=FALSE)

graph.rdaTest(s$results[[1]], plot.type = "Z",groups=toto[[1]][,4], lty.env=0, lty.spc=0, ell=FALSE, stars=TRUE, label.site=FALSE,xlim=c(-1,1),ylim=c(-1,1))

}
\keyword{graphs}
\keyword{multivariate}
