\name{horizontal.transects}
\alias{horizontal.transects}
\docType{data}
\title{ Data set: Imported sonar data acquired from horizontal transects}
\description{
  This RData file is the saved output of the \code{\link{import.imatxt}} function. This data file contains a small random subset of only 500 lines, extracted from a much larger file containing data from a continuous horizontal 
sonar transect, fluctuating in altitude from 1 to 5 m above the seafloor.
}
\usage{data(horizontal.transects)}
\format{
  This list contains 4 elements:
  
	\item{ datum }{ This matrix contains the sonar return intensities. In the 
		first column are found the times and dates of acquisition, in seconds 
		past midnight of the reference date.
	}
	\item{ limits }{ This matrix contains the starting and ending times of the
		two transects read by the \code{\link{import.imatxt}} function.
 	}
	\item{ j.refdate }{ A numerical value describing the reference date. See 
		\code{\link{Date}}.
	}
	\item{ path }{ The paths to the sonar files read by the \code{\link{extract}} 
		function. 
	}
}

\details{
   The sonar returns reprensented in this dataset are also described by the \code{\link{VIS.analysis}} dataset, which provides a visual description of the benthos that served as a basis to identify variables that are sensible to the visual characteristics.
}
\examples{
# #This load the original data set imported using import.imatxt function 
# #These are sonar data acquired through horizontal transects. 
data(horizontal.transects)
names(horizontal.transects)

# #The following command extracts and treats the data set.
# #Option "avesec" is set to TRUE because these data will be linked 
# #to VIS.analysis. All echoes found within the same second are averaged 
# #when avesec=TRUE. This will allow a comparison to be made between the
# #two data files, second by second.
# #extract.data<-extract(import.datum=horizontal.transects, avesec=TRUE)

# #Instead of recomputing the extraction (previous command), 
# #get the data from the saved dataset:
# data(INTextract) 

# #Get the visual data
# data(VIS.analysis)

# #Redundancy analysis (RDA), which is an option of the "analyse" 
# #function, is used for the joint analysis of the two files:
# #the sonar data will be explained by the visual data.
# res<-analyse(extract.data=extract.data, VIS=VIS.analysis, alt.sect=NULL, 
#	use="VT", keep=NA, class.vec=NULL, validation.perc=0.30, 
#	nperm=9, criterion="Calinski", select.grpmt=FALSE, flag=2, 
#	method="RDA", grpmts.plot=TRUE)
}

\keyword{datasets}
