\name{import.imatxt}
\alias{import.imatxt}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ This function imports and reads .TXT Imagenex sonar files }
\description{
	This function can import one or several Imagenex(TM) sonar files, so that they can be forwarded to the \code{extract} function, and later analysed with the \code{analyse} function.
}
\usage{
import.imatxt(
	path=NA, number.file=NA, echolength=NA, limits=NA, 
	dateformat="\%d-\%b-\%Y", timesep=":", remove.all=TRUE, see=TRUE
	)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{path}{ A vector of paths to the .TXT imagenex files. These files were obtained by converting the .81b format files to .TXT.  The conversion program used in our case is called 81b2txt.exe and was provided by Imagenex corp. To convert the sonar files to .TXT, users should contact their sonar company to obtain an adapted file converting program.
  }
  \item{number.file}{ If no path is provided in \code{"path"}, this parameter defines how many files are to be selected using a browser. The default is \code{NA}. If \code{path} is defined, its length redefines \code{number.file}.
  }
  \item{echolength}{ 	How long is each echo. In other words, how many intensity values make up each echo. The default is NA. 
  }
  \item{limits}{ The complete path to a file describing the limits of the data sections that are to be retained for analysis, i.e. their starting and ending times. The file \code{data(keep.sequences)} shows how such a file should be written. The purpose of these limits is to prevent averaging consecutive echoes acquired in different areas. If the file paths to sonar transect provided in \code{path} are individual transects, no value is required here since the time limits of each transect are known; they will be used as limits. The default value is \code{NA}. 
  }
  \item{dateformat}{ Date format used. See \code{strptime} to find out how to use this parameter. The default is \code{"\%d-\%b-\%Y"}, which stands for day-month abreviation, and year in four digits. 
  }
  \item{timesep}{ Time format separator used. Default is \code{":"}. 
  }
  \item{remove.all}{ To make sure all echoes provided are temporally ordered, a filter is used to find all echoes labelled by erroneous or non chronological times. If set to \code{TRUE}, these echoes are removed; if set to \code{FALSE}, the erroneous times are shown to the user who is asked to decide what to do. If, after five passes, errors are still found, a warning message appears: transect were probably listed in the wrong order.
  }
  \item{see}{ Shows the erroneous times, and in which files the erroneous times were found. The default is \code{TRUE}. }
}
\details{
  The transects given must be entered in chronological order.
}
\value{
   \item{ datum }{ The sonar data matrix ready to be send to \code{extract}. 	
		\describe{
  			\item{ \code{Column.1} }{ Contains the time in seconds past
  			midnight, to which we add 86400 seconds for every day afterthe
  			reference date.
  			}
  			\item{ \code{Column.2} }{ The sonar head angle. 0 degree means
  			facing straight down, perpendicular to the substratum.
  			}
  			\item{ \code{Column.3} }{ The estimated acquisition altitude in 
  			metres.
  			}
  			\item{ \code{Column.4-...} }{ The equally-spaced intensity values 
  			used to describe the sonar returns. 
  			}
		}
  	}
  \item{ limits }{ The starting and ending times of each separate transect found in the data matrix \code{"datum"}, in seconds past midnight. These limits will prevent the averaging of sonar returns acquired in different transects or at different locations.
  }
  \item{ path }{ The path of the input files entered. }
}
\author{ Sebastien Durand <Sebastien.Durand@UMontreal.ca> }
\note{ Please contact me if you are using another type of sonar file. Make sure that in your E-mail, you state the sonar type and program version you are using, and attach a small sample of your sonar data files. These files must be editable, and not under any unusual compressed format. Also, provide a quick definition for all fields (columns) in the file. 	
}

\section{Warning }{ Please note, this is a beta version ...}

\seealso{
	\code{\link{extract}},
	\code{\link{analyse}},
	\code{\link{Date}} 
}
\examples{
# Usually, the user has first to import their txt files.
# Here is an example, unfortunatly the original files 
# could not be stored in this package
# The sonar imagenex file paths are given to R
# path=c("LAVA1","LAVA2","LAVA3","LAVA4","PERI1","PERI2",
# "PERI3","TUBE1","TUBE2",#"TUBE3","TUBE4","LIMP1","LIMP2",
# "LIMP3","CLAM1","CLAM2","CLAM3","CLAM4")
# path=paste("~/.../ALT",path,".TXT",sep="")
# The files were imported using import.imatxt function
# vertical.transects<-import.imatxt(path=path, number.file=NA, 
#	echolength=2000, limits=NA, dateformat="\%d-\%b-\%Y", 
#	timesep=":", remove.all=TRUE, see=TRUE)
# Creating a smaller subset
# tmp<-sample(1:dim(vertical.transects$datum)[1], 1000)	
# vertical.transects$datum<-vertical.transects$datum[tmp[order(tmp)],]
# save(vertical.transects,file="~/../sonarX/data/vertical.transects.rda", 
# compress=TRUE)
# That is the data available
}
\keyword{manip}
