\name{ldaTest}
\alias{ldaTest}
\title{ Compute a linear discriminant analysis }
\description{
  This function performs linear discriminant analysis and computes additional statistical results which may facilitate the interpretation.
}
\usage{
ldaTest(X.mat, group, print.res = TRUE, alpha = 0.05, cross = NULL)
}
\arguments{
  \item{X.mat}{ X.mat (nxm) contains the explanatory variables for the dispersion among groups. The number of variables (m) is recomputed after eliminating collinear explanatory variables. 
  }
  \item{group}{ A vector or factor of length (n) describing the group membership of every object described in \code{X.mat}.
  }
  \item{print.res}{ If \code{TRUE}: print most of ldaTest output on the screen. 
  }
  \item{alpha}{ Significance level for tests; the default value is 5\%.
  }
  \item{cross}{ The percentage of objects that will be used to create the model. The remaining objects will be used in cross-validation. The default is \code{NULL}; in that case, 100\% of the objects will be used to create the model and they will then all be used for prediction. 
  }
}
\value{
  The function returns an output list containing the following ELEMENTS:
  
  \item{ VIF }{ Variance inflation factors for the explanatory variables X; the value is 0 for entirely collinear variables.
  }
  \item{ canEigval }{ Canonical eigenvalues.
  }
  \item{ C }{ Calculate the C matrix "Final vectors for the explanatory variables", of size (pxk).
  }
  \item{ F.model }{ Matrix (n1xk) of object scores for the constructed model.
  }
  \item{ F.predict }{ Matrix (n2xk) of object scores for the object used for prediction.
  }
  \item{ Stats }{
  	\item{ Homo }{ Using Kullback's statistic, we test the hypothesis of homogeneity of the within-group dispersion matrices.
  }
  	\item{ Axes }{ Results of Wilks'ratio test of significance for all axes together, then after removing the first axis, and so on until the remaining axes are no longer significant. 
  }
  }
  \item{ Class.Ftn }{ Matrix (kxp) of weights given by the canonical functions.
  }
  \item{ Scores }{ Matrix describing the scores obtained using the classification functions with the objects.  It \code{cross} is not NULL nor 100\%, the \code{Scores} matrix describes only the object that were not used to construct the discrimant model.
  }
  \item{ Grp.Mod }{ The groups originally observed for the (n1) objects used to construct the model.
  }
  \item{ Grp.Obs }{ The groups originally observed for the (n2) objects used to validate the model.
  }
  \item{ Grp.Ass }{ The groups assigned, using the model, to the (n2) objects used to validate the model.
  }
   \item{ Grp.Ctr.Mod }{ Group centroids based on the Grp.Mod groups.
  }
   \item{ Grp.Ctr.Mod }{ Group centroids based on the Grp.Obs groups.
  }
   \item{ Grp.Ctr.Mod }{ Group centroids based on the Grp.Ass groups.
  }
  \item{ Class.Table }{ The group classification (or "confusion") table.
  }
  
}
\references{ Legendre, P. and L. Legendre. 1998. Numerical Ecology. Second English Edition. Elsevier, Amsterdam. }
\author{ Pierre Legendre, Sebastien Durand, Universite de Montreal. }
\seealso{ \code{\link{graph.ldaTest}} }
\examples{
#	Example 1, from Legendre & Legendre (Numerical ecology, 1998) p. 626
XY.mat<-matrix(c(1,2,2,8,8,8,9,2,2,1,7,6,3,3),7,2,byrow=FALSE)
groups<-c(1,1,1,2,2,3,3)
results <- ldaTest(XY.mat,group=groups)
graph.ldaTest(results, ell=FALSE)

#	Example 2
XY.mat2<-rbind(XY.mat,XY.mat+0.5,XY.mat-0.5,XY.mat+0.2,XY.mat-0.2,XY.mat+0.3,XY.mat-0.3)
groups2=c("La","La","La","BE","BE","CO","CO")
groups2=c(rep(groups2,7))

colnames(XY.mat2)=c("Ell1","Ell2")
rownames(XY.mat2)=paste("a",1:nrow(XY.mat2))

#	Construct a model using 40\% of the data and use the remaining 60\% for 
#	prediction by cross-validation
results <- ldaTest(XY.mat2, group=groups2,print.res=FALSE,cross=0.4,alpha=0.9)

#	Plot the model with the observed groups; reverse axis 1
graph.ldaTest(results,plot.what="model", xax=-1, yax=2, lty.ell=2,
	col.ell="dark green", ell.axis=TRUE, pos.ctd=4)

#   Plot the predictions with the assigned groups. Variable Ell1 in column 1 is binary 
graph.ldaTest(results, xax=1, yax=2, binary=1, pos.ctd=1)

#	The ellipse drawn seem large. This is because they represent a 95\%
#	confidence intervals and the number of objects is small.

}
\keyword{multivariate}
