\name{rdaTest}
\alias{rdaTest}
\alias{FractionBySpecies}

%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Compute a canonical redundancy analysis }
\description{
  This function computes simple redundancy analysis (RDA) for partial RDA, with permutation tests, following the algorithm described in Numerical Ecology, Chapter 11 (Legendre & Legendre, 1998).
}
\usage{
rdaTest(
	YY.mat, XX.mat, which.cov=NULL, scale.Y=FALSE, testF=NULL, 
	nperm=999, print.res=TRUE, print.cum=FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{

  \item{ YY.mat }{ The (nxp) site-by-species data table.
  }
  \item{ XX.mat }{ The (nxm) table of explanatory variables. The number of variables (m) is recomputed after eliminating collinear explanatory variables, if any. Covariables, if any, are also found in that table.
  }
  \item{ which.cov }{ A vector (1xmax(m-1)) defining the covariables by their column numbers in XX.mat.
  }
  \item{ scale.Y }{ A logical value (TRUE or FALSE) defining if YY.mat should be standardized (TRUE), or only centred on the column means (FALSE).
  }
  \item{ testF }{ If NULL, the program will ask the user if he/she wishes to test the F statistic. If testF is TRUE or FALSE, no question will be asked; the program will perform the test, or not, in accordance with that indication. 
  }
  \item{ nperm }{ Number of permutations for the F test. If NULL, a question will be asked by the program. 
  }
  \item{ print.res }{ Prints most of the rdaTest output on the screen. 
  }
  \item{ print.cum }{ Prints the fractions of the response variable's (e.g. species) variances explained by canonical axes 1, 2, 3, ... and by the whole canonical analysis. 
  }
}
\value{
  If print.res = TRUE, the function prints the following information to the R window:
- The variance inflation factors for the explanatory variables (the covariables are not included in these calculations).
- The bimultivariate redundancy statistic (canonical R-square), as well as the adjusted R-square when there are no covariables in the analysis.
- Test of significance of the canonical relationship: the F statistic and permutational probability. Note: the degrees of freedom of F are not corrected for collinearity between the explanatory variables and the covariables. This has no influence on the associated permutational probability.
- The number of objects, number of response variables, and number of explanatory variables after removing collinear variables; the number of canonical eigenvalues larger than 0.
- The total variance in matrix YY.mat, i.e., the SS/(n-1).
- The eigenvalues, relative eigenvalues, and the cumulative \% the variance of species data accounted for by the sucessive canonical eigenvalues.
  The function also returns an output list containing the following ELEMENTS:
  \item{ VIF }{ Variance inflation factors for the explanatory variables X; the value is 0 for entirely collinear variables. The covariables are not included in this calculation. 
  }
  \item{ canEigval }{ Canonical eigenvalues.
  }
  \item{ U }{ (pxk) Canonical eigenvectors normalized to 1 (scaling 1). 
  }
  \item{ USc2 }{ (pxk) Canonical eigenvectors normalized to sqrt(eigenvalue) (scaling 2). 
  }
  \item{ F }{ (nxk) Matrix of object scores (scaling 1). 
  }
  \item{ Z }{ (nxk) Matrix of fitted object scores (scaling 1). 
  }
  \item{ FSc2 }{ Matrix of object scores (scaling 2). 
  }
  \item{ ZSc2 }{ Matrix of fitted object scores (scaling 2). 
  }
  \item{ biplotScores1 }{ Biplot scores of explanatory variables (scaling 1). 
  }
  \item{ biplotScores2 }{ Biplot scores of explanatory variables (scaling 2). 
  }
  \item{ FitSpe }{ Table of cumulative fit per species (in \%) as fraction of variance of species. 
  }
  \item{ VarExpl }{ Vector of total \% fit per species after all canonical axes. 
  }
  \item{ ProbFrda }{ Probability associated with F test of the canonical relationship. 
  }	
  \item{ X.mat }{ Original X matrix (required by the plotting function). 
  }
  \item{ AxisVar }{ Eigenvalues as in Canoco: fraction of variance of YY.mat explained by each canonical axis. 
  }
}
\references{ Legendre, P. and L. Legendre. 1998. Numerical Ecology. Second English Edition. Elsevier, Amsterdam. }
\author{ Pierre Legendre and Sebastien Durand, Universite de Montreal.
 }
\note{ This is a beta version. }

\seealso{ \code{\link{graph.rdaTest}}}
\examples{
# Example from Legendre & Legendre (1998), p. 590, Table 11.3	
data(coral)
Table = as.matrix(coral)
Y=Table[,1:6]
X=Table[,7:10]

# Numerical Ecology
resultats <- rdaTest(Y,X,nperm=99,testF=TRUE)
graph.rdaTest(resultats,plot.type="F",stars=FALSE,lty.ell=3, centroid=FALSE)

#or
graph.rdaTest(resultats,plot.type="F",lty.ell=3,pos.site=4, mai.perc=0.15)

resultats <- rdaTest(Y,X,testF=TRUE,nperm=9,scale.Y=FALSE,
print.res=FALSE, print.cum=FALSE)
graph.rdaTest(resultats,xax=-1,yax=2, mul.spc=0.90, 
mul.env=0.70, mul.text=0.10, scaling=1, 
plot.type="F",mai.perc=0.15, stars=FALSE, pos.site=4, centroid=FALSE)
}
\keyword{multivariate}
